/*
** 2000-05-29
**
** The author disclaims copyright to this source code.  In place of
** a legal notice, here is a blessing:
**
**    May you do good and not evil.
**    May you find forgiveness for yourself and forgive others.
**    May you share freely, never taking more than you give.
**
*************************************************************************
** Driver template for the LEMON parser generator.
**
** The "lemon" program processes an LALR(1) input grammar file, then uses
** this template to construct a parser.  The "lemon" program inserts text
** at each "%%" line.  Also, any "P-a-r-s-e" identifer prefix (without the
** interstitial "-" characters) contained in this template is changed into
** the value of the %name directive from the grammar.  Otherwise, the content
** of this template is copied straight through into the generate parser
** source file.
**
** The following is the concatenation of all %include directives from the
** input grammar file:
*/
#include <stdio.h>
#include <stdbool.h>
/************ Begin %include sections from the grammar ************************/
#line 56 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"

#include "sqlInt.h"
#include "box/fk_constraint.h"

/*
** Disable all error recovery processing in the parser push-down
** automaton.
*/
#define YYNOERRORRECOVERY 1

/*
** Make yytestcase() the same as testcase()
*/
#define yytestcase(X) testcase(X)

/*
** Indicate that sqlParserFree() will never be called with a null
** pointer.
*/
#define YYPARSEFREENEVERNULL 1

/*
** Alternative datatype for the argument to the malloc() routine passed
** into sqlParserAlloc().  The default is size_t.
*/
#define YYMALLOCARGTYPE  u64

/*
 * Stop the parser if an error occurs. This macro adds an
 * additional check that allows the parser to be stopped if any
 * error was noticed.
 */
#define PARSER_ERROR_CHECK && ! pParse->is_aborted

/*
** An instance of this structure holds information about the
** LIMIT clause of a SELECT statement.
*/
struct LimitVal {
  Expr *pLimit;    /* The LIMIT expression.  NULL if there is no limit */
  Expr *pOffset;   /* The OFFSET expression.  NULL if there is none */
};

/*
** An instance of the following structure describes the event of a
** TRIGGER.  "a" is the event type, one of TK_UPDATE, TK_INSERT,
** TK_DELETE, or TK_INSTEAD.  If the event is of the form
**
**      UPDATE ON (a,b,c)
**
** Then the "b" IdList records the list "a,b,c".
*/
struct TrigEvent { int a; IdList * b; };

/*
** Disable lookaside memory allocation for objects that might be
** shared across database connections.
*/
static void disableLookaside(Parse *pParse){
  pParse->disableLookaside++;
  pParse->db->lookaside.bDisable++;
}

#line 479 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"

  /**
   * For a compound SELECT statement, make sure
   * p->pPrior->pNext==p for all elements in the list. And make
   * sure list length does not exceed SQL_LIMIT_COMPOUND_SELECT.
   */
  static void parserDoubleLinkSelect(Parse *pParse, Select *p){
    if( p->pPrior ){
      Select *pNext = 0, *pLoop;
      int mxSelect, cnt = 0;
      for(pLoop=p; pLoop; pNext=pLoop, pLoop=pLoop->pPrior, cnt++){
        pLoop->pNext = pNext;
        pLoop->selFlags |= SF_Compound;
      }
      if( (p->selFlags & SF_MultiValue)==0 && 
        (mxSelect = pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT])>0 &&
        cnt>mxSelect
      ){
         diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of UNION or "\
                  "EXCEPT or INTERSECT operations", cnt,
                  pParse->db->aLimit[SQL_LIMIT_COMPOUND_SELECT]);
         pParse->is_aborted = true;
      }
    }
  }
#line 964 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"

  /* This is a utility routine used to set the ExprSpan.zStart and
  ** ExprSpan.zEnd values of pOut so that the span covers the complete
  ** range of text beginning with pStart and going to the end of pEnd.
  */
  static void spanSet(ExprSpan *pOut, Token *pStart, Token *pEnd){
    pOut->zStart = pStart->z;
    pOut->zEnd = &pEnd->z[pEnd->n];
  }

  /* Construct a new Expr object from a single identifier.  Use the
  ** new Expr to populate pOut.  Set the span of pOut to be the identifier
  ** that created the expression.
  */
  static void spanExpr(ExprSpan *pOut, Parse *pParse, int op, Token t){
    struct Expr *p = NULL;
    int name_sz = t.n + 1;
    p = sqlDbMallocRawNN(pParse->db, sizeof(Expr) + name_sz);
    if( p ){
      memset(p, 0, sizeof(Expr));
      switch (op) {
      case TK_STRING:
        p->type = FIELD_TYPE_STRING;
        break;
      case TK_BLOB:
        p->type = FIELD_TYPE_VARBINARY;
        break;
      case TK_INTEGER:
        p->type = FIELD_TYPE_INTEGER;
        break;
      case TK_FLOAT:
        p->type = FIELD_TYPE_DOUBLE;
        break;
      case TK_DECIMAL:
        p->type = FIELD_TYPE_DECIMAL;
        break;
      case TK_TRUE:
      case TK_FALSE:
      case TK_UNKNOWN:
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      case TK_VARIABLE:
        /*
         * For variables we set BOOLEAN type since
         * unassigned bindings will be replaced
         * with NULL automatically, i.e. without
         * explicit call of sql_bind_*().
         */
        p->type = FIELD_TYPE_BOOLEAN;
        break;
      default:
        p->type = FIELD_TYPE_SCALAR;
        break;
      }
      p->op = (u8)op;
      p->flags = EP_Leaf;
      p->iAgg = -1;
      p->u.zToken = (char*)&p[1];
      if (op != TK_VARIABLE) {
        int rc = sql_normalize_name(p->u.zToken, name_sz, t.z, t.n);
        if (rc > name_sz) {
          name_sz = rc;
          p = sqlDbReallocOrFree(pParse->db, p, sizeof(*p) + name_sz);
          if (p == NULL)
            goto tarantool_error;
          p->u.zToken = (char *) &p[1];
          if (sql_normalize_name(p->u.zToken, name_sz, t.z, t.n) > name_sz)
              unreachable();
        }
      } else {
        memcpy(p->u.zToken, t.z, t.n);
        p->u.zToken[t.n] = 0;
      }
#if SQL_MAX_EXPR_DEPTH>0
      p->nHeight = 1;
#endif  
    }
    pOut->pExpr = p;
    pOut->zStart = t.z;
    pOut->zEnd = &t.z[t.n];
    return;
tarantool_error:
    sqlDbFree(pParse->db, p);
    pParse->is_aborted = true;
  }
#line 1241 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"

  /* This routine constructs a binary expression node out of two ExprSpan
  ** objects and uses the result to populate a new ExprSpan object.
  */
  static void spanBinaryExpr(
    Parse *pParse,      /* The parsing context.  Errors accumulate here */
    int op,             /* The binary operation */
    ExprSpan *pLeft,    /* The left operand, and output */
    ExprSpan *pRight    /* The right operand */
  ){
    pLeft->pExpr = sqlPExpr(pParse, op, pLeft->pExpr, pRight->pExpr);
    pLeft->zEnd = pRight->zEnd;
  }

  /* If doNot is true, then add a TK_NOT Expr-node wrapper around the
  ** outside of *ppExpr.
  */
  static void exprNot(Parse *pParse, int doNot, ExprSpan *pSpan){
    if( doNot ){
      pSpan->pExpr = sqlPExpr(pParse, TK_NOT, pSpan->pExpr, 0);
    }
  }
#line 1315 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"

  /* Construct an expression node for a unary postfix operator
  */
  static void spanUnaryPostfix(
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand, and output */
    Token *pPostOp         /* The operand token for setting the span */
  ){
    pOperand->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOperand->zEnd = &pPostOp->z[pPostOp->n];
  }                           
#line 1336 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"

  /* Construct an expression node for a unary prefix operator
  */
  static void spanUnaryPrefix(
    ExprSpan *pOut,        /* Write the new expression node here */
    Parse *pParse,         /* Parsing context to record errors */
    int op,                /* The operator */
    ExprSpan *pOperand,    /* The operand */
    Token *pPreOp         /* The operand token for setting the span */
  ){
    pOut->zStart = pPreOp->z;
    pOut->pExpr = sqlPExpr(pParse, op, pOperand->pExpr, 0);
    pOut->zEnd = pOperand->zEnd;
  }
#line 1538 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"

  /* Add a single new term to an ExprList that is used to store a
  ** list of identifiers.  Report an error if the ID list contains
  ** a COLLATE clause or an ASC or DESC keyword, except ignore the
  ** error while parsing a legacy schema.
  */
  static ExprList *parserAddExprIdListTerm(
    Parse *pParse,
    ExprList *pPrior,
    Token *pIdToken
  ){
    ExprList *p = sql_expr_list_append(pParse->db, pPrior, NULL);
    sqlExprListSetName(pParse, p, pIdToken, 1);
    return p;
  }
#line 1754 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"

  struct alter_args {
    struct SrcList *table_name;
    /** Name of constraint OR new name of table in case of RENAME. */
    struct Token name;
  };
#line 279 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
/**************** End of %include directives **********************************/
/* These constants specify the various numeric values for terminal symbols
** in a format understandable to "makeheaders".  This section is blank unless
** "lemon" is run with the "-m" command-line option.
***************** Begin makeheaders token definitions *************************/
/**************** End makeheaders token definitions ***************************/

/* The next sections is a series of control #defines.
** various aspects of the generated parser.
**    YYCODETYPE         is the data type used to store the integer codes
**                       that represent terminal and non-terminal symbols.
**                       "unsigned char" is used if there are fewer than
**                       256 symbols.  Larger types otherwise.
**    YYNOCODE           is a number of type YYCODETYPE that is not used for
**                       any terminal or nonterminal symbol.
**    YYFALLBACK         If defined, this indicates that one or more tokens
**                       (also known as: "terminal symbols") have fall-back
**                       values which should be used if the original symbol
**                       would not parse.  This permits keywords to sometimes
**                       be used as identifiers, for example.
**    YYACTIONTYPE       is the data type used for "action codes" - numbers
**                       that indicate what to do in response to the next
**                       token.
**    sqlParserTOKENTYPE     is the data type used for minor type for terminal
**                       symbols.  Background: A "minor type" is a semantic
**                       value associated with a terminal or non-terminal
**                       symbols.  For example, for an "ID" terminal symbol,
**                       the minor type might be the name of the identifier.
**                       Each non-terminal can have a different minor type.
**                       Terminal symbols all have the same minor type, though.
**                       This macros defines the minor type for terminal 
**                       symbols.
**    YYMINORTYPE        is the data type used for all minor types.
**                       This is typically a union of many types, one of
**                       which is sqlParserTOKENTYPE.  The entry in the union
**                       for terminal symbols is called "yy0".
**    YYSTACKDEPTH       is the maximum depth of the parser's stack.  If
**                       zero the stack is dynamically sized using realloc()
**    sqlParserARG_SDECL     A static variable declaration for the %extra_argument
**    sqlParserARG_PDECL     A parameter declaration for the %extra_argument
**    sqlParserARG_STORE     Code to store %extra_argument into yypParser
**    sqlParserARG_FETCH     Code to extract %extra_argument from yypParser
**    YYERRORSYMBOL      is the code number of the error symbol.  If not
**                       defined, then do no error processing.
**    YYNSTATE           the combined number of states.
**    YYNRULE            the number of rules in the grammar
**    YY_MAX_SHIFT       Maximum value for shift actions
**    YY_MIN_SHIFTREDUCE Minimum value for shift-reduce actions
**    YY_MAX_SHIFTREDUCE Maximum value for shift-reduce actions
**    YY_MIN_REDUCE      Maximum value for reduce actions
**    YY_ERROR_ACTION    The yy_action[] code for syntax error
**    YY_ACCEPT_ACTION   The yy_action[] code for accept
**    YY_NO_ACTION       The yy_action[] code for no-op
*/
#ifndef INTERFACE
# define INTERFACE 1
#endif
/************* Begin control #defines *****************************************/
#define YYCODETYPE unsigned short int
#define YYNOCODE 276
#define YYACTIONTYPE unsigned short int
#define YYWILDCARD 76
#define sqlParserTOKENTYPE Token
typedef union {
  int yyinit;
  sqlParserTOKENTYPE yy0;
  struct LimitVal yy14;
  Expr* yy22;
  int yy42;
  TriggerStep* yy77;
  With* yy81;
  struct alter_args yy90;
  struct ExprList * yy163;
  ExprSpan yy192;
  SrcList* yy197;
  struct Token yy237;
  struct type_def yy320;
  struct Expr * yy369;
  IdList* yy430;
  enum trim_side_mask yy445;
  struct SrcList * yy458;
  Select* yy509;
  struct TrigEvent yy510;
  bool yy537;
  ExprList* yy542;
} YYMINORTYPE;
#ifndef YYSTACKDEPTH
#define YYSTACKDEPTH 100
#endif
#define sqlParserARG_SDECL Parse *pParse;
#define sqlParserARG_PDECL ,Parse *pParse
#define sqlParserARG_FETCH Parse *pParse = yypParser->pParse
#define sqlParserARG_STORE yypParser->pParse = pParse
#define YYFALLBACK 1
#define YYNSTATE             442
#define YYNRULE              322
#define YY_MAX_SHIFT         441
#define YY_MIN_SHIFTREDUCE   666
#define YY_MAX_SHIFTREDUCE   987
#define YY_MIN_REDUCE        988
#define YY_MAX_REDUCE        1309
#define YY_ERROR_ACTION      1310
#define YY_ACCEPT_ACTION     1311
#define YY_NO_ACTION         1312
/************* End control #defines *******************************************/

/* Define the yytestcase() macro to be a no-op if is not already defined
** otherwise.
**
** Applications can choose to define yytestcase() in the %include section
** to a macro that can assist in verifying code coverage.  For production
** code the yytestcase() macro should be turned off.  But it is useful
** for testing.
*/
#ifndef yytestcase
# define yytestcase(X)
#endif


/* Next are the tables used to determine what action to take based on the
** current state and lookahead token.  These tables are used to implement
** functions that take a state number and lookahead value and return an
** action integer.  
**
** Suppose the action integer is N.  Then the action is determined as
** follows
**
**   0 <= N <= YY_MAX_SHIFT             Shift N.  That is, push the lookahead
**                                      token onto the stack and goto state N.
**
**   N between YY_MIN_SHIFTREDUCE       Shift to an arbitrary state then
**     and YY_MAX_SHIFTREDUCE           reduce by rule N-YY_MIN_SHIFTREDUCE.
**
**   N between YY_MIN_REDUCE            Reduce by rule N-YY_MIN_REDUCE
**     and YY_MAX_REDUCE
**
**   N == YY_ERROR_ACTION               A syntax error has occurred.
**
**   N == YY_ACCEPT_ACTION              The parser accepts its input.
**
**   N == YY_NO_ACTION                  No such action.  Denotes unused
**                                      slots in the yy_action[] table.
**
** The action table is constructed as a single large table named yy_action[].
** Given state S and lookahead X, the action is computed as either:
**
**    (A)   N = yy_action[ yy_shift_ofst[S] + X ]
**    (B)   N = yy_default[S]
**
** The (A) formula is preferred.  The B formula is used instead if:
**    (1)  The yy_shift_ofst[S]+X value is out of range, or
**    (2)  yy_lookahead[yy_shift_ofst[S]+X] is not equal to X, or
**    (3)  yy_shift_ofst[S] equal YY_SHIFT_USE_DFLT.
** (Implementation note: YY_SHIFT_USE_DFLT is chosen so that
** YY_SHIFT_USE_DFLT+X will be out of range for all possible lookaheads X.
** Hence only tests (1) and (2) need to be evaluated.)
**
** The formulas above are for computing the action when the lookahead is
** a terminal symbol.  If the lookahead is a non-terminal (as occurs after
** a reduce action) then the yy_reduce_ofst[] array is used in place of
** the yy_shift_ofst[] array and YY_REDUCE_USE_DFLT is used in place of
** YY_SHIFT_USE_DFLT.
**
** The following are the tables generated in this section:
**
**  yy_action[]        A single table containing all actions.
**  yy_lookahead[]     A table containing the lookahead for each entry in
**                     yy_action.  Used to detect hash collisions.
**  yy_shift_ofst[]    For each state, the offset into yy_action for
**                     shifting terminals.
**  yy_reduce_ofst[]   For each state, the offset into yy_action for
**                     shifting non-terminals after a reduce.
**  yy_default[]       Default action for each state.
**
*********** Begin parsing tables **********************************************/
#define YY_ACTTAB_COUNT (1661)
static const YYACTIONTYPE yy_action[] = {
 /*     0 */    55,  943,   65,   65,   65,   65,   64,   64,   63,   63,
 /*    10 */    63,   62,  319,  324,  927,  326,  128,   52,   53,  978,
 /*    20 */   978,  311,  128,  321,   54,  321,  165,  329,  293,  195,
 /*    30 */   195,  963,  169,  296,  293,  425,    3,  976,  321,  296,
 /*    40 */   817,  393,  320,  320,  963,   63,   63,   63,   62,  319,
 /*    50 */   750,  136,  953,   64,   64,   63,   63,   63,   62,  319,
 /*    60 */   986,  414,  667,  323,  683,  968,  297,   61,   59,  194,
 /*    70 */     7,  968,  812,  319,  977,  697,  977,  979,  766,  937,
 /*    80 */   938,  939,  940,  941,  942,  944,  945,  946,  281,  949,
 /*    90 */   950,  951,  951,  952,  435,  170,   67,   67,   67,   67,
 /*   100 */   814,   65,   65,   65,   65,   64,   64,   63,   63,   63,
 /*   110 */    62,  319,   86,   86,  816,  816,  818,  819,  820,  821,
 /*   120 */   822,  823,  433,   10,  227,  428,  834,  835,  836,  981,
 /*   130 */    21,   68,   69,  298,  318,  849,  849,  859,  862,   66,
 /*   140 */    66,   67,   67,   67,   67,   55,   65,   65,   65,   65,
 /*   150 */    64,   64,   63,   63,   63,   62,  319,  778,  137,  435,
 /*   160 */   263,  262,   52,   53,  777,  408,   29,  780,  427,   54,
 /*   170 */   378,  376,  382,  977,  810,  977,  817,  105,  105,  922,
 /*   180 */   425,    3, 1196,  136,  375,  817,  779,  320,  320,   67,
 /*   190 */    67,   67,   67,   60,   65,   65,   65,   65,   64,   64,
 /*   200 */    63,   63,   63,   62,  319,  914,  414,  395,  812,  763,
 /*   210 */   119,   61,   59,  194,  409,  391,  435,  812,   61,   59,
 /*   220 */   194,  915,  924,  227,  687,  180,  192,   61,   59,  194,
 /*   230 */   924,  916,  730,  427,  105,  105, 1311,  441,    1,  731,
 /*   240 */   348,  684,  684,   62,  319,  814,   61,   59,  194,  334,
 /*   250 */   816,  816,  818,  819,  820,  821,  822,  234,  390,  816,
 /*   260 */   816,  818,  819,  820,  821,  822,  823,  433,   10,  201,
 /*   270 */   428,  409,  396,  920,  981,   21,   68,   69,  298,  318,
 /*   280 */   849,  849,  859,  862,   66,   66,   67,   67,   67,   67,
 /*   290 */   427,   65,   65,   65,   65,   64,   64,   63,   63,   63,
 /*   300 */    62,  319,   68,   69,  298,  318,  849,  849,  859,  862,
 /*   310 */    66,   66,   67,   67,   67,   67,   55,   65,   65,   65,
 /*   320 */    65,   64,   64,   63,   63,   63,   62,  319,  977,  806,
 /*   330 */   977,  968,  297,   52,   53,  729,  729,  968,  195,  195,
 /*   340 */    54,  697,  700,  200,  385,   43,  242,  344,  325,  132,
 /*   350 */   393,  425,    3,  435,  136,  739,  817,  887,  320,  320,
 /*   360 */   978,  978,  234,  390,   70,  342,  393,  332,  435,  781,
 /*   370 */   782,   24,   24,  383,  694,  382,  222,  414,  227,  136,
 /*   380 */   254,  349,  897,  783,  784,  300,  105,  105,  812,   68,
 /*   390 */    69,  298,  318,  849,  849,  859,  862,   66,   66,   67,
 /*   400 */    67,   67,   67,  806,   65,   65,   65,   65,   64,   64,
 /*   410 */    63,   63,   63,   62,  319,  897,  814,  747,  979,  765,
 /*   420 */   253,  354,  746,  315,  175,  174,  357,  427,  357,  258,
 /*   430 */   816,  816,  818,  819,  820,  821,  822,  823,  433,   10,
 /*   440 */    55,  428,  427,   72,  435,  981,   21,  817,  440,  440,
 /*   450 */   684,  684,  289,  763,  254,  435,  133,   52,   53,  751,
 /*   460 */   727,  727,  105,  105,   54,  368,  365,   55,  700,  684,
 /*   470 */   684,  880,  136,   24,   24,  425,    3,  279,  235,  812,
 /*   480 */   817,  885,  320,  320,   52,   53,  257,  306,  923,  136,
 /*   490 */   397,   54,  737,  795,  207,   74,  213,  435,  714,  409,
 /*   500 */   405,  414,  425,    3,  891,  341,  380,  817,  434,  320,
 /*   510 */   320,  715,  812,  806,  301,  105,  105,   51,  427,   49,
 /*   520 */   136,  816,  816,  818,  819,  820,  821,  822,  414,  427,
 /*   530 */   253,  354,  312,  398,  389,  250,  742,  742,  406,  812,
 /*   540 */   814,  119,  177,  176,  127,  690,  292,  157,  911,  263,
 /*   550 */   262,  119,  409,  407,  816,  816,  818,  819,  820,  821,
 /*   560 */   822,  823,  433,   10,  254,  428,   44,  814,  247,  981,
 /*   570 */    21,  427,  160,  923,  423,  190,  355, 1254, 1254,  764,
 /*   580 */   853,  816,  816,  818,  819,  820,  821,  822,  823,  433,
 /*   590 */    10,  696,  428,  263,  262,  364,  981,   21,   68,   69,
 /*   600 */   298,  318,  849,  849,  859,  862,   66,   66,   67,   67,
 /*   610 */    67,   67,  435,   65,   65,   65,   65,   64,   64,   63,
 /*   620 */    63,   63,   62,  319,  689,  246,   61,   59,  194,  911,
 /*   630 */   103,  103,  119,  850,  850,  860,  863,  925,  183,  764,
 /*   640 */   708,  709,  710,   68,   69,  298,  318,  849,  849,  859,
 /*   650 */   862,   66,   66,   67,   67,   67,   67,  355,   65,   65,
 /*   660 */    65,   65,   64,   64,   63,   63,   63,   62,  319,  764,
 /*   670 */   245,   75,  154,  894,  244,  893,  353,  682,  684,  684,
 /*   680 */   684,  684,  695,  347,  372,  278,  427,  331,   68,   69,
 /*   690 */   298,  318,  849,  849,  859,  862,   66,   66,   67,   67,
 /*   700 */    67,   67,  394,   65,   65,   65,   65,   64,   64,   63,
 /*   710 */    63,   63,   62,  319,  803,  279,  155,  119,   76,  432,
 /*   720 */    23,   23,  684,  684,  684,  684,  810,  688,  183,  764,
 /*   730 */   763,  763,  706,   68,   69,  298,  318,  849,  849,  859,
 /*   740 */   862,   66,   66,   67,   67,   67,   67,  914,   65,   65,
 /*   750 */    65,   65,   64,   64,   63,   63,   63,   62,  319,  757,
 /*   760 */     2,  909,  682,  915,  119,  763,  684,  684,  361,  261,
 /*   770 */   241,  208,  840,  916,  413,  763,  427,  707,   68,   69,
 /*   780 */   298,  318,  849,  849,  859,  862,   66,   66,   67,   67,
 /*   790 */    67,   67,  303,   65,   65,   65,   65,   64,   64,   63,
 /*   800 */    63,   63,   62,  319,  432,  209,  193,  192,  724,  363,
 /*   810 */   363,  362,  419,  226,  363,  917,  724,  811,  783,  784,
 /*   820 */    68,   69,  298,  318,  849,  849,  859,  862,   66,   66,
 /*   830 */    67,   67,   67,   67,  400,   65,   65,   65,   65,   64,
 /*   840 */    64,   63,   63,   63,   62,  319,   68,   69,  298,  318,
 /*   850 */   849,  849,  859,  862,   66,   66,   67,   67,   67,   67,
 /*   860 */   763,   65,   65,   65,   65,   64,   64,   63,   63,   63,
 /*   870 */    62,  319,   68,   69,  298,  318,  849,  849,  859,  862,
 /*   880 */    66,   66,   67,   67,   67,   67,  752,   65,   65,   65,
 /*   890 */    65,   64,   64,   63,   63,   63,   62,  319,  212,  252,
 /*   900 */   886,  763,  736,  215,  965,  119,  182,  747,  683,  684,
 /*   910 */   684,  416,  746,  412,  119,  810,  810,  810,  352,  420,
 /*   920 */   424,   45,  119,  119,  187,  359,  889,   68,   69,  298,
 /*   930 */   318,  849,  849,  859,  862,   66,   66,   67,   67,   67,
 /*   940 */    67,  733,   65,   65,   65,   65,   64,   64,   63,   63,
 /*   950 */    63,   62,  319,   68,   69,  298,  318,  849,  849,  859,
 /*   960 */   862,   66,   66,   67,   67,   67,   67,  435,   65,   65,
 /*   970 */    65,   65,   64,   64,   63,   63,   63,   62,  319,   55,
 /*   980 */    47,  304,  305,  316,  964,   24,   24,  203,  683,  185,
 /*   990 */   233,  885,  815,  763,   40,  270,   52,   53,  720,  308,
 /*  1000 */    28,  885,  763,   54,  926,  327,   50,  435,   42,  229,
 /*  1010 */   178,  179,  808,  272,  425,    3,  225,  435,  196,  817,
 /*  1020 */   274,  320,  320,  356,  307,   26,   26,  225,   56,  435,
 /*  1030 */   181,  435,  721,  732,  317,   83,   83,  277,  309,  358,
 /*  1040 */   414,  427,  249,  225,  162,  129,   11,  105,  105,  105,
 /*  1050 */   105,  812,   69,  298,  318,  849,  849,  859,  862,   66,
 /*  1060 */    66,   67,   67,   67,   67,  240,   65,   65,   65,   65,
 /*  1070 */    64,   64,   63,   63,   63,   62,  319,  931,  879,  814,
 /*  1080 */  1006,  427,   42,  929,  409,  426,  409,  429,  373,  698,
 /*  1090 */   698,  427,  229,  816,  816,  818,  819,  820,  821,  822,
 /*  1100 */   823,  433,   10,  427,  428,  427,  713,  712,  981,   21,
 /*  1110 */    68,   69,  298,  318,  849,  849,  859,  862,   66,   66,
 /*  1120 */    67,   67,   67,   67,  921,   65,   65,   65,   65,   64,
 /*  1130 */    64,   63,   63,   63,   62,  319,   68,   58,  298,  318,
 /*  1140 */   849,  849,  859,  862,   66,   66,   67,   67,   67,   67,
 /*  1150 */   798,   65,   65,   65,   65,   64,   64,   63,   63,   63,
 /*  1160 */    62,  319,  298,  318,  849,  849,  859,  862,   66,   66,
 /*  1170 */    67,   67,   67,   67,  919,   65,   65,   65,   65,   64,
 /*  1180 */    64,   63,   63,   63,   62,  319,  439,  314,  671,  438,
 /*  1190 */   237,  290, 1021,  435,  677,  930,  267,  723,  314,  136,
 /*  1200 */   336,   42,  722,  343,  435,  302,   36,  435,  337,  266,
 /*  1210 */   310,   78,   78,  744,  773,  883,  435,   46,  225,  229,
 /*  1220 */   338,  310,   24,   24, 1288,  105,  105,  243, 1288,  435,
 /*  1230 */   824,  824,  435,  345,   88,   88,  403,  435,  186,  960,
 /*  1240 */   908,  251,  435,   13,  906,  339,  360,  105,  105,  295,
 /*  1250 */    82,   82,  905,  366,  367,   89,   89,  235,  172,  268,
 /*  1260 */    90,   90,  409,  386, 1288,  256,  676,  427,  235,  172,
 /*  1270 */   268,  340,  261,  387,  435,  700,  119,  435,  427,  260,
 /*  1280 */   693,  427,  265,  261,  401,  771,  809,  388,  276,  435,
 /*  1290 */   427,  435,   91,   91,  435,   92,   92,  205,  753,  435,
 /*  1300 */   884,  435,  415,  427,  335,  435,  427,   27,   27,   79,
 /*  1310 */    79,  427,   81,   81,  435,  280,  427,   93,   93,   94,
 /*  1320 */    94,  435,    9,   95,   95,  435,  286,  435,  299,  171,
 /*  1330 */   161,  435,   25,   25,  435,  685,  435,  674,  435,   96,
 /*  1340 */    96,  435,  673,   97,   97,   98,   98,  675,  427,   99,
 /*  1350 */    99,  427,  100,  100,   84,   84,  101,  101,  435,  102,
 /*  1360 */   102,  152,  435,  427,  435,  427,  239,  435,  427,  130,
 /*  1370 */    40,  794,  120,  427,  435,  427,   85,   85,  141,  427,
 /*  1380 */   124,  124,  125,  125,  346,  126,  126,  143,  427,  145,
 /*  1390 */   892,  210,  109,  109,  351,  427,  147,   31,  435,  427,
 /*  1400 */   435,  427,  435,  248,  435,  427,  371,  148,  427,  211,
 /*  1410 */   427,  435,  427,  218,  910,  427,  104,  104,   87,   87,
 /*  1420 */   112,  112,  106,  106,  435,  156,  435,  805,  369,  113,
 /*  1430 */   113,  435,  427,  435,  219,  435,  427,  435,  427,  435,
 /*  1440 */   121,  427,  111,  111,  123,  123,  435,  163,  427,  118,
 /*  1450 */   118,  117,  117,  116,  116,  114,  114,  115,  115,  220,
 /*  1460 */   313,  259,  718,  435,  108,  108,  379,  703,  435,  381,
 /*  1470 */   435,  704,  427,  435,  427,  122,  427,  264,  427,  717,
 /*  1480 */   384,  110,  110,  399,  692,  427,  107,  107,   77,   77,
 /*  1490 */    39,   80,   80,  761,  691,    8,  867,   48,  427,  269,
 /*  1500 */   427,  418,  228,  422,  271,  427,  762,  427,  760,  427,
 /*  1510 */   273,  427,  759,  427,  431,  275,   71,  948,  743,  404,
 /*  1520 */   427,  282,   41,  283,  402,  284,  285,  437,  961,  287,
 /*  1530 */   294,    4,  288,  957,  236,  238,   12,  427,   73,  669,
 /*  1540 */   322,  959,  427,  928,  427,   14,   30,  427,  197,  138,
 /*  1550 */   198,  328,  330,  199,  333,  202,  139,  890,  173,  204,
 /*  1560 */   206,  140,  142,  804,  144,  134,  734,  146,  895,  225,
 /*  1570 */   149,  150,  983,  350,  904,  151,  153,   32,   33,   34,
 /*  1580 */    35,  135,  907,  903,  214,  216,   22,  255,   15,  217,
 /*  1590 */   164,  679,  370,  266,  221,  158,  374,   16,   17,  377,
 /*  1600 */   178,   37,  716,  839,  223,  179,  131,  741,   38,  392,
 /*  1610 */   188,  837,  865,   18,  826,  745,  189,    6,  224,  191,
 /*  1620 */   159,   19,  878,  866,  417,  421,  772,  767,   46,   42,
 /*  1630 */   864,  827,   20,  913,  184,  410,  912,  935,  411,  166,
 /*  1640 */   436,  936,  230,  869,  167,  232,  868,  168,  854,  838,
 /*  1650 */   231,    5,  430,  947,  825,   57,  291,  670,  680,  666,
 /*  1660 */  1276,
};
static const YYCODETYPE yy_lookahead[] = {
 /*     0 */     7,   75,   20,   21,   22,   23,   24,   25,   26,   27,
 /*    10 */    28,   29,   30,   80,   81,   82,  175,   24,   25,   49,
 /*    20 */    50,   85,  175,  182,   31,  184,  185,   94,  187,  217,
 /*    30 */   218,  184,  185,  192,  187,   42,   43,   48,  197,  192,
 /*    40 */    47,  229,   49,   50,  197,   26,   27,   28,   29,   30,
 /*    50 */   233,   45,  126,   24,   25,   26,   27,   28,   29,   30,
 /*    60 */   186,   68,    1,    2,  190,  191,  192,  250,  251,  252,
 /*    70 */    43,  197,   79,   30,   47,  201,   49,  107,  108,  153,
 /*    80 */   154,  155,  156,  157,  158,  159,  160,  161,  162,  163,
 /*    90 */   164,  165,  166,  167,  175,  106,   15,   16,   17,   18,
 /*   100 */   107,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   110 */    29,   30,  193,  194,  121,  122,  123,  124,  125,  126,
 /*   120 */   127,  128,  129,  130,   97,  132,  133,  134,  135,  136,
 /*   130 */   137,    5,    6,    7,    8,    9,   10,   11,   12,   13,
 /*   140 */    14,   15,   16,   17,   18,    7,   20,   21,   22,   23,
 /*   150 */    24,   25,   26,   27,   28,   29,   30,  196,  200,  175,
 /*   160 */   202,  203,   24,   25,  196,  246,  247,  190,  249,   31,
 /*   170 */    80,   81,   82,   47,  175,   49,   47,  193,  194,  175,
 /*   180 */    42,   43,   44,   45,   94,   47,  190,   49,   50,   15,
 /*   190 */    16,   17,   18,   19,   20,   21,   22,   23,   24,   25,
 /*   200 */    26,   27,   28,   29,   30,   35,   68,  216,   79,  175,
 /*   210 */   219,  250,  251,  252,  230,  231,  175,   79,  250,  251,
 /*   220 */   252,   51,  201,   97,  193,  234,  235,  250,  251,  252,
 /*   230 */   209,   61,   62,  249,  193,  194,  169,  170,  171,   69,
 /*   240 */   241,   49,   50,   29,   30,  107,  250,  251,  252,  215,
 /*   250 */   121,  122,  123,  124,  125,  126,  127,  102,  103,  121,
 /*   260 */   122,  123,  124,  125,  126,  127,  128,  129,  130,   77,
 /*   270 */   132,  230,  231,  269,  136,  137,    5,    6,    7,    8,
 /*   280 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   290 */   249,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   300 */    29,   30,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   310 */    13,   14,   15,   16,   17,   18,    7,   20,   21,   22,
 /*   320 */    23,   24,   25,   26,   27,   28,   29,   30,   47,   69,
 /*   330 */    49,  191,  192,   24,   25,  212,  213,  197,  217,  218,
 /*   340 */    31,  201,   84,  151,   26,   48,   86,   87,  271,   53,
 /*   350 */   229,   42,   43,  175,   45,  218,   47,  193,   49,   50,
 /*   360 */    49,   50,  102,  103,   67,  244,  229,   71,  175,   73,
 /*   370 */    74,  193,  194,   80,   81,   82,   83,   68,   97,   45,
 /*   380 */   120,   86,   87,  112,  113,  207,  193,  194,   79,    5,
 /*   390 */     6,    7,    8,    9,   10,   11,   12,   13,   14,   15,
 /*   400 */    16,   17,   18,   69,   20,   21,   22,   23,   24,   25,
 /*   410 */    26,   27,   28,   29,   30,  120,  107,   99,  107,  108,
 /*   420 */    86,   87,  104,  230,   24,   25,  175,  249,  175,   39,
 /*   430 */   121,  122,  123,  124,  125,  126,  127,  128,  129,  130,
 /*   440 */     7,  132,  249,   43,  175,  136,  137,   47,  172,  173,
 /*   450 */    49,   50,  176,  175,  120,  175,  180,   24,   25,   26,
 /*   460 */   212,  213,  193,  194,   31,  256,  257,    7,   84,   49,
 /*   470 */    50,   81,   45,  193,  194,   42,   43,  175,   77,   79,
 /*   480 */    47,  175,   49,   50,   24,   25,   96,  207,  189,   45,
 /*   490 */     7,   31,  216,  215,  243,  219,  243,  175,   57,  230,
 /*   500 */   231,   68,   42,   43,   60,   78,   65,   47,    7,   49,
 /*   510 */    50,   70,   79,   69,  208,  193,  194,  138,  249,  140,
 /*   520 */    45,  121,  122,  123,  124,  125,  126,  127,   68,  249,
 /*   530 */    86,   87,   91,   50,   98,  145,  100,  101,  216,   79,
 /*   540 */   107,  219,  266,  267,  268,  193,  270,  200,  216,  202,
 /*   550 */   203,  219,  230,  231,  121,  122,  123,  124,  125,  126,
 /*   560 */   127,  128,  129,  130,  120,  132,  106,  107,   39,  136,
 /*   570 */   137,  249,  152,  274,  272,   44,  244,  102,  103,   48,
 /*   580 */    79,  121,  122,  123,  124,  125,  126,  127,  128,  129,
 /*   590 */   130,  200,  132,  202,  203,  263,  136,  137,    5,    6,
 /*   600 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   610 */    17,   18,  175,   20,   21,   22,   23,   24,   25,   26,
 /*   620 */    27,   28,   29,   30,  193,   96,  250,  251,  252,  216,
 /*   630 */   193,  194,  219,    9,   10,   11,   12,   44,  107,  108,
 /*   640 */    88,   89,   90,    5,    6,    7,    8,    9,   10,   11,
 /*   650 */    12,   13,   14,   15,   16,   17,   18,  244,   20,   21,
 /*   660 */    22,   23,   24,   25,   26,   27,   28,   29,   30,   48,
 /*   670 */   141,  258,   43,   54,  145,   56,  263,  189,   49,   50,
 /*   680 */    49,   50,   44,   64,    7,  248,  249,  242,    5,    6,
 /*   690 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   700 */    17,   18,  175,   20,   21,   22,   23,   24,   25,   26,
 /*   710 */    27,   28,   29,   30,  216,  175,   43,  219,   43,  189,
 /*   720 */   193,  194,   49,   50,   49,   50,  175,   44,  107,  108,
 /*   730 */   175,  175,  204,    5,    6,    7,    8,    9,   10,   11,
 /*   740 */    12,   13,   14,   15,   16,   17,   18,   35,   20,   21,
 /*   750 */    22,   23,   24,   25,   26,   27,   28,   29,   30,  236,
 /*   760 */    43,  216,  274,   51,  219,  175,   49,   50,    7,   92,
 /*   770 */   215,  215,   44,   61,   62,  175,  249,  204,    5,    6,
 /*   780 */     7,    8,    9,   10,   11,   12,   13,   14,   15,   16,
 /*   790 */    17,   18,  241,   20,   21,   22,   23,   24,   25,   26,
 /*   800 */    27,   28,   29,   30,  274,  215,  234,  235,  201,  175,
 /*   810 */   175,   50,  272,  233,  175,  215,  209,   44,  112,  113,
 /*   820 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*   830 */    15,   16,   17,   18,  240,   20,   21,   22,   23,   24,
 /*   840 */    25,   26,   27,   28,   29,   30,    5,    6,    7,    8,
 /*   850 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*   860 */   175,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*   870 */    29,   30,    5,    6,    7,    8,    9,   10,   11,   12,
 /*   880 */    13,   14,   15,   16,   17,   18,   26,   20,   21,   22,
 /*   890 */    23,   24,   25,   26,   27,   28,   29,   30,  264,  264,
 /*   900 */   215,  175,  216,  264,  186,  219,  240,   99,  190,   49,
 /*   910 */    50,  216,  104,  213,  219,  175,  175,  175,  260,  216,
 /*   920 */   216,  106,  219,  219,   48,  175,   44,    5,    6,    7,
 /*   930 */     8,    9,   10,   11,   12,   13,   14,   15,   16,   17,
 /*   940 */    18,  215,   20,   21,   22,   23,   24,   25,   26,   27,
 /*   950 */    28,   29,   30,    5,    6,    7,    8,    9,   10,   11,
 /*   960 */    12,   13,   14,   15,   16,   17,   18,  175,   20,   21,
 /*   970 */    22,   23,   24,   25,   26,   27,   28,   29,   30,    7,
 /*   980 */   139,  241,  241,  241,  186,  193,  194,  105,  190,  259,
 /*   990 */   222,  175,  175,  175,  118,  233,   24,   25,   59,  207,
 /*  1000 */   232,  175,  175,   31,   44,   44,  139,  175,   48,   48,
 /*  1010 */    86,   87,   44,  233,   42,   43,   48,  175,   43,   47,
 /*  1020 */   233,   49,   50,   44,  208,  193,  194,   48,  106,  175,
 /*  1030 */   175,  175,   93,  215,  208,  193,  194,  175,  206,   44,
 /*  1040 */    68,  249,  215,   48,  220,   97,  221,  193,  194,  193,
 /*  1050 */   194,   79,    6,    7,    8,    9,   10,   11,   12,   13,
 /*  1060 */    14,   15,   16,   17,   18,  175,   20,   21,   22,   23,
 /*  1070 */    24,   25,   26,   27,   28,   29,   30,  175,   44,  107,
 /*  1080 */   105,  249,   48,  175,  230,  231,  230,  231,   44,   49,
 /*  1090 */    50,  249,   48,  121,  122,  123,  124,  125,  126,  127,
 /*  1100 */   128,  129,  130,  249,  132,  249,   78,   79,  136,  137,
 /*  1110 */     5,    6,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  1120 */    15,   16,   17,   18,  175,   20,   21,   22,   23,   24,
 /*  1130 */    25,   26,   27,   28,   29,   30,    5,    6,    7,    8,
 /*  1140 */     9,   10,   11,   12,   13,   14,   15,   16,   17,   18,
 /*  1150 */   224,   20,   21,   22,   23,   24,   25,   26,   27,   28,
 /*  1160 */    29,   30,    7,    8,    9,   10,   11,   12,   13,   14,
 /*  1170 */    15,   16,   17,   18,  175,   20,   21,   22,   23,   24,
 /*  1180 */    25,   26,   27,   28,   29,   30,   32,    7,   34,   35,
 /*  1190 */    36,   37,    1,  175,   40,  175,   79,   44,    7,   45,
 /*  1200 */   175,   48,   44,  237,  175,  175,   48,  175,  175,   92,
 /*  1210 */    30,  193,  194,   44,   44,   44,  175,   48,   48,   48,
 /*  1220 */   175,   30,  193,  194,   44,  193,  194,  237,   48,  175,
 /*  1230 */    49,   50,  175,  175,  193,  194,  207,  175,  175,   44,
 /*  1240 */   224,  265,  175,   48,  175,   91,  265,  193,  194,   95,
 /*  1250 */   193,  194,  175,  175,  175,  193,  194,   77,   78,   79,
 /*  1260 */   193,  194,  230,  231,   84,  175,  175,  249,   77,   78,
 /*  1270 */    79,  117,   92,  216,  175,   84,  219,  175,  249,  175,
 /*  1280 */   196,  249,  175,   92,  230,  175,  175,  230,  237,  175,
 /*  1290 */   249,  175,  193,  194,  175,  193,  194,  143,  175,  175,
 /*  1300 */   175,  175,  255,  249,  150,  175,  249,  193,  194,  193,
 /*  1310 */   194,  249,  193,  194,  175,  175,  249,  193,  194,  193,
 /*  1320 */   194,  175,  221,  193,  194,  175,  223,  175,    9,  221,
 /*  1330 */    43,  175,  193,  194,  175,  175,  175,  175,  175,  193,
 /*  1340 */   194,  175,  175,  193,  194,  193,  194,  175,  249,  193,
 /*  1350 */   194,  249,  193,  194,  193,  194,  193,  194,  175,  193,
 /*  1360 */   194,   43,  175,  249,  175,  249,  198,  175,  249,    5,
 /*  1370 */   118,  224,  199,  249,  175,  249,  193,  194,  245,  249,
 /*  1380 */   193,  194,  193,  194,   41,  193,  194,  211,  249,  214,
 /*  1390 */   262,  214,  193,  194,  147,  249,  214,  138,  175,  249,
 /*  1400 */   175,  249,  175,  261,  175,  249,   41,  214,  249,  181,
 /*  1410 */   249,  175,  249,  181,  224,  249,  193,  194,  193,  194,
 /*  1420 */   193,  194,  193,  194,  175,  211,  175,  211,  198,  193,
 /*  1430 */   194,  175,  249,  175,  181,  175,  249,  175,  249,  175,
 /*  1440 */   199,  249,  193,  194,  193,  194,  175,  245,  249,  193,
 /*  1450 */   194,  193,  194,  193,  194,  193,  194,  193,  194,  181,
 /*  1460 */    63,  198,  205,  175,  193,  194,   85,  202,  175,   85,
 /*  1470 */   175,  203,  249,  175,  249,  199,  249,  198,  249,  205,
 /*  1480 */    85,  193,  194,  110,  195,  249,  193,  194,  193,  194,
 /*  1490 */    85,  193,  194,  239,  195,   43,  253,  138,  249,  238,
 /*  1500 */   249,  198,  254,  198,  238,  249,  239,  249,  239,  249,
 /*  1510 */   238,  249,  239,  249,   43,  238,  116,  273,  228,  111,
 /*  1520 */   249,  227,  115,  226,  114,  225,  224,   46,  183,   45,
 /*  1530 */   178,   43,  177,   36,  174,  174,  188,  249,  188,    4,
 /*  1540 */     3,  179,  249,   66,  249,   43,   43,  249,   83,   43,
 /*  1550 */    77,   66,   82,   38,   95,   77,   39,   44,   14,   43,
 /*  1560 */   142,   39,  119,  103,  106,   91,   42,   85,  146,   48,
 /*  1570 */   146,   85,  149,  148,    1,  106,  119,   14,   14,   14,
 /*  1580 */    14,   91,   50,    1,  109,  105,  144,  141,   43,   85,
 /*  1590 */    97,   42,    7,   92,   83,   43,   66,   43,   43,   66,
 /*  1600 */    86,   43,   52,   44,   66,   87,   58,   99,   48,   48,
 /*  1610 */   105,   44,   44,   43,  131,   44,   44,   43,  109,   44,
 /*  1620 */    43,  109,   44,   44,   97,   97,   50,  108,   48,   48,
 /*  1630 */    44,   44,  109,   44,   43,   47,   44,   44,   48,   43,
 /*  1640 */    14,   44,   48,   60,   43,  105,   44,   43,   79,   44,
 /*  1650 */    43,   43,  127,   44,   44,   43,   38,   33,   47,    1,
 /*  1660 */     0,
};
#define YY_SHIFT_USE_DFLT (1661)
#define YY_SHIFT_COUNT    (441)
#define YY_SHIFT_MIN      (-74)
#define YY_SHIFT_MAX      (1660)
static const short yy_shift_ofst[] = {
 /*     0 */    61, 1154,  138,  309,  401,   -7,  972,  972,  972,  972,
 /*    10 */   972,  972, 1191,  401,  972,  972,  972,  972,  972,  972,
 /*    20 */   972,  972,  334,  126,  271,  271,  384,  384,  433,  460,
 /*    30 */   972,  972,  972,  972,  972,  972,  972,  972,  972,  972,
 /*    40 */   972,  972,  972,  972,  972,  972,  972,  972,  972,  972,
 /*    50 */   972,  972,  972,  972,  972,  972,  972,  972,  972,  972,
 /*    60 */   972,  972,  972,  972,  972,  972,  972,  972,  972,  972,
 /*    70 */   972,  972,  972, 1180,  260,  444,  475,  297,  593,  638,
 /*    80 */   683,  728,  773,  815,  841,  867,  922,  948, 1105, 1105,
 /*    90 */  1105, 1105, 1105, 1105, 1105, 1105, 1105, 1105, 1105, 1105,
 /*   100 */  1105, 1105, 1105, 1105, 1105, 1105, 1131, 1105, 1046, 1155,
 /*   110 */  1155,  174,   81,   81,   81,  -18,   29,   19,  214,  155,
 /*   120 */   -64,  -64,  -64,   43, 1661, 1661, 1661,  -74,  -74,  -74,
 /*   130 */   170,  170,  192,  390,  629,  629,  420,  677,  631,  631,
 /*   140 */   631,  427,  631,  631,  631,  631,  631,  631,  631,  631,
 /*   150 */   631,  631,  631,  631,  631,  631,  631,  677,  631,  631,
 /*   160 */   631,  631,  155,    6,    6,  258,    6,    6,    6,  258,
 /*   170 */  1661, 1661,  400,  129,  129,  129,  -67,  296,  441,  441,
 /*   180 */   531,   27,  -30,  311,  712,  295,  619,  673,  860,  281,
 /*   190 */   281,  281,  675,  621,  717,  436,  318,  631,  631,  631,
 /*   200 */   631,  631,  631,  631,  631,  631,  631,  876,  483,  483,
 /*   210 */   631,  631,  761,  876,  631,  761,  631,  631,  631,  631,
 /*   220 */   631,  631,  631,  706,  631,  631,  483,  631,  379,  631,
 /*   230 */   631,  808,  631,  -11,  808,  631,  631,  631,  631, 1319,
 /*   240 */  1287, 1318, 1364, 1252, 1343, 1343, 1343, 1343, 1259, 1247,
 /*   250 */  1365, 1252, 1318, 1364, 1364, 1365, 1287, 1365, 1365, 1319,
 /*   260 */  1287, 1397, 1381, 1384, 1319, 1287, 1397, 1395, 1395, 1373,
 /*   270 */  1405, 1373, 1405, 1373, 1405, 1373, 1405, 1452, 1359, 1287,
 /*   280 */  1287, 1471, 1400, 1408, 1407, 1410, 1252, 1481, 1484, 1488,
 /*   290 */  1497, 1497, 1661, 1661, 1661,  529,   90,  293,  624,  552,
 /*   300 */   960,  961,  882,  968,  979,  995, 1034, 1044, 1153, 1158,
 /*   310 */  1040,  924, 1028,  939, 1117, 1169, 1170, 1171,  501, 1181,
 /*   320 */   975, 1195, 1535, 1537, 1477, 1502, 1503, 1465, 1506, 1485,
 /*   330 */  1473, 1470, 1515, 1478, 1459, 1517, 1513, 1516, 1544, 1418,
 /*   340 */  1522, 1460, 1443, 1474, 1458, 1482, 1524, 1422, 1521, 1424,
 /*   350 */  1423, 1425, 1486, 1573, 1469, 1457, 1563, 1564, 1565, 1566,
 /*   360 */  1490, 1532, 1475, 1480, 1582, 1442, 1545, 1504, 1446, 1493,
 /*   370 */  1549, 1585, 1501, 1511, 1552, 1530, 1554, 1555, 1533, 1514,
 /*   380 */  1550, 1518, 1558, 1538, 1548, 1559, 1567, 1568, 1560, 1508,
 /*   390 */  1570, 1571, 1574, 1561, 1505, 1572, 1575, 1576, 1509, 1577,
 /*   400 */  1519, 1580, 1512, 1581, 1523, 1578, 1579, 1586, 1587, 1580,
 /*   410 */  1589, 1588, 1590, 1592, 1591, 1583, 1593, 1596, 1527, 1594,
 /*   420 */  1597, 1601, 1528, 1594, 1602, 1604, 1605, 1607, 1608, 1483,
 /*   430 */  1609, 1525, 1610, 1612, 1569, 1540, 1611, 1626, 1618, 1624,
 /*   440 */  1658, 1660,
};
#define YY_REDUCE_USE_DFLT (-189)
#define YY_REDUCE_COUNT (294)
#define YY_REDUCE_MIN   (-188)
#define YY_REDUCE_MAX   (1362)
static const short yy_reduce_ofst[] = {
 /*     0 */    67,  276,  322, 1057, -159,  -81,  -16,   41,  269,  854,
 /*    10 */   856, 1032, -126, -153,  178,  280,  792,  832,  193, 1054,
 /*    20 */  1029,  437,  413, -183,  -39,  -32,  -23,   -4,  527,  842,
 /*    30 */  1018, 1041, 1062, 1067, 1099, 1102, 1114, 1116, 1119, 1124,
 /*    40 */  1126, 1130, 1139, 1146, 1150, 1152, 1156, 1159, 1161, 1163,
 /*    50 */  1166, 1183, 1187, 1189, 1192, 1199, 1223, 1225, 1227, 1229,
 /*    60 */  1236, 1249, 1251, 1256, 1258, 1260, 1262, 1264, 1271, 1288,
 /*    70 */  1293, 1295, 1298,  140,  121,  332,   -9,  376,  376,  376,
 /*    80 */   376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
 /*    90 */   376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
 /*   100 */   376,  376,  376,  376,  376,  376,  376,  376,  376,  376,
 /*   110 */   376,  376,  376,  376,  376,  376,  376,  376,  376, -188,
 /*   120 */   -42,  347,  391,  376,  376,  376,  376,  299,  488,  530,
 /*   130 */   123,  248,    4,  209,  251,  253,  302,   21,  306,   34,
 /*   140 */   278,  498,  555,  556,  590,  600,  685,  726,  818,   -1,
 /*   150 */   827,  634,  551,  635,  740,  741,  639,  607,  816,  742,
 /*   160 */   540,  826,  137,  545,  686,  718,  695,  703,  704,  798,
 /*   170 */   572,  768,   31,  164,  352,  431,   77,  445,  528,  573,
 /*   180 */   523,  580,  594,  666,  700,  658,  730,  750,  817,  762,
 /*   190 */   780,  787,  855,  523,  862,  824,  825,  890,  902,  908,
 /*   200 */   949,  999, 1020, 1025, 1030, 1033, 1045,  926,  966,  990,
 /*   210 */  1058, 1063,  976, 1016, 1069,  981, 1077, 1078, 1079, 1090,
 /*   220 */  1091, 1104, 1107, 1084, 1110, 1111, 1051, 1123, 1047, 1125,
 /*   230 */  1140, 1101,  817, 1103, 1108, 1160, 1162, 1167, 1172, 1173,
 /*   240 */  1168, 1133, 1176, 1147, 1175, 1177, 1182, 1193, 1128, 1142,
 /*   250 */  1228, 1190, 1202, 1214, 1216, 1232, 1230, 1253, 1278, 1241,
 /*   260 */  1263, 1257, 1265, 1268, 1276, 1279, 1274, 1289, 1299, 1254,
 /*   270 */  1261, 1267, 1266, 1269, 1272, 1273, 1277, 1243, 1248, 1303,
 /*   280 */  1305, 1244, 1290, 1294, 1297, 1300, 1302, 1345, 1352, 1355,
 /*   290 */  1360, 1361, 1348, 1350, 1362,
};
static const YYACTIONTYPE yy_default[] = {
 /*     0 */  1277, 1254, 1254, 1254, 1008, 1310, 1196, 1196, 1196, 1196,
 /*    10 */  1196, 1196, 1008, 1008, 1310, 1310, 1310, 1310, 1310, 1310,
 /*    20 */  1310, 1154, 1254, 1076, 1107, 1107, 1021, 1021, 1310, 1310,
 /*    30 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 /*    40 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 /*    50 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 /*    60 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 /*    70 */  1310, 1310, 1310, 1008, 1310, 1254, 1080, 1113, 1310, 1310,
 /*    80 */  1310, 1197, 1198, 1310, 1310, 1310, 1153, 1310, 1224, 1124,
 /*    90 */  1123, 1122, 1121, 1090, 1119, 1111, 1115, 1151, 1150, 1197,
 /*   100 */  1193, 1194, 1192, 1155, 1152, 1198, 1310, 1114, 1164, 1177,
 /*   110 */  1163, 1173, 1183, 1174, 1166, 1165, 1167, 1168, 1169, 1310,
 /*   120 */  1027, 1027, 1027, 1170, 1180, 1179, 1178, 1310, 1310, 1310,
 /*   130 */  1310, 1310, 1310, 1203, 1310, 1310, 1310, 1047, 1310, 1310,
 /*   140 */  1310, 1254, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 /*   150 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1047, 1310, 1310,
 /*   160 */  1310, 1310, 1310, 1254, 1254, 1021, 1254, 1254, 1254, 1021,
 /*   170 */  1080, 1071, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 /*   180 */  1310, 1076, 1310, 1310, 1310, 1310, 1218, 1310, 1310, 1076,
 /*   190 */  1076, 1076, 1310, 1078, 1310, 1060, 1070, 1310, 1310, 1310,
 /*   200 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1118, 1092, 1092,
 /*   210 */  1310, 1310, 1307, 1118, 1310, 1307, 1310, 1310, 1310, 1310,
 /*   220 */  1310, 1310, 1310, 1107, 1310, 1310, 1092, 1310, 1195, 1310,
 /*   230 */  1310, 1070, 1310, 1077, 1070, 1310, 1310, 1310, 1310, 1033,
 /*   240 */  1204, 1129, 1050, 1118, 1057, 1057, 1057, 1057, 1223, 1222,
 /*   250 */  1000, 1118, 1129, 1050, 1050, 1000, 1204, 1000, 1000, 1033,
 /*   260 */  1204, 1041, 1024, 1023, 1033, 1204, 1041, 1048, 1048, 1096,
 /*   270 */  1091, 1096, 1091, 1096, 1091, 1096, 1091, 1199, 1310, 1204,
 /*   280 */  1204, 1310, 1112, 1097, 1110, 1108, 1118, 1310, 1284, 1310,
 /*   290 */  1280, 1280, 1291, 1291, 1003, 1310, 1310, 1310, 1310, 1310,
 /*   300 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 /*   310 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 /*   320 */  1135, 1310, 1310,  990, 1310, 1310, 1310, 1310, 1310, 1310,
 /*   330 */  1310, 1310, 1310, 1310, 1240, 1310, 1310, 1210, 1310, 1310,
 /*   340 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1221, 1220,
 /*   350 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 /*   360 */  1310, 1310, 1310, 1306, 1310, 1310, 1310, 1310, 1310, 1310,
 /*   370 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,
 /*   380 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1062,
 /*   390 */  1310, 1310, 1310, 1297, 1310, 1310, 1310, 1310, 1310, 1310,
 /*   400 */  1310, 1109, 1310, 1098, 1310, 1310, 1310, 1310, 1310, 1304,
 /*   410 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310, 1256,
 /*   420 */  1310, 1310, 1310, 1255, 1310, 1310, 1310, 1310, 1310, 1310,
 /*   430 */  1310, 1310, 1310, 1310, 1310, 1310, 1310, 1310,  994, 1310,
 /*   440 */  1310, 1310,
};
/********** End of lemon-generated parsing tables *****************************/

/* The next table maps tokens (terminal symbols) into fallback tokens.  
** If a construct like the following:
** 
**      %fallback ID X Y Z.
**
** appears in the grammar, then ID becomes a fallback token for X, Y,
** and Z.  Whenever one of the tokens X, Y, or Z is input to the parser
** but it does not parse, the type of the token is changed to ID and
** the parse is retried before an error is thrown.
**
** This feature can be used, for example, to cause some keywords in a language
** to revert to identifiers if they keyword does not apply in the context where
** it appears.
*/
#ifdef YYFALLBACK
static const YYCODETYPE yyFallback[] = {
    0,  /*          $ => nothing */
    0,  /*       SEMI => nothing */
    0,  /*    EXPLAIN => nothing */
   49,  /*      QUERY => ID */
   49,  /*       PLAN => ID */
    0,  /*         OR => nothing */
    0,  /*        AND => nothing */
    0,  /*        NOT => nothing */
    0,  /*         IS => nothing */
   49,  /*      MATCH => ID */
    0,  /*    LIKE_KW => nothing */
    0,  /*    BETWEEN => nothing */
    0,  /*         IN => nothing */
    0,  /*         NE => nothing */
    0,  /*         EQ => nothing */
    0,  /*         GT => nothing */
    0,  /*         LE => nothing */
    0,  /*         LT => nothing */
    0,  /*         GE => nothing */
    0,  /*     ESCAPE => nothing */
    0,  /*     BITAND => nothing */
    0,  /*      BITOR => nothing */
    0,  /*     LSHIFT => nothing */
    0,  /*     RSHIFT => nothing */
    0,  /*       PLUS => nothing */
    0,  /*      MINUS => nothing */
    0,  /*       STAR => nothing */
    0,  /*      SLASH => nothing */
    0,  /*        REM => nothing */
    0,  /*     CONCAT => nothing */
    0,  /*    COLLATE => nothing */
    0,  /*     BITNOT => nothing */
    0,  /*      START => nothing */
    0,  /* TRANSACTION => nothing */
    0,  /*     COMMIT => nothing */
    0,  /*   ROLLBACK => nothing */
    0,  /*  SAVEPOINT => nothing */
   49,  /*    RELEASE => ID */
    0,  /*         TO => nothing */
    0,  /*      TABLE => nothing */
    0,  /*     CREATE => nothing */
   49,  /*         IF => ID */
    0,  /*     EXISTS => nothing */
    0,  /*         LP => nothing */
    0,  /*         RP => nothing */
    0,  /*       WITH => nothing */
   49,  /*     ENGINE => ID */
    0,  /*     STRING => nothing */
    0,  /*      COMMA => nothing */
    0,  /*         ID => nothing */
    0,  /*    INDEXED => nothing */
   49,  /*      ABORT => ID */
   49,  /*     ACTION => ID */
   49,  /*        ADD => ID */
   49,  /*      AFTER => ID */
   49,  /* AUTOINCREMENT => ID */
   49,  /*     BEFORE => ID */
   49,  /*    CASCADE => ID */
   49,  /*   CONFLICT => ID */
   49,  /*   DEFERRED => ID */
   49,  /*        END => ID */
   49,  /*       FAIL => ID */
   49,  /*     IGNORE => ID */
   49,  /*  INITIALLY => ID */
   49,  /*    INSTEAD => ID */
   49,  /*         NO => ID */
   49,  /*        KEY => ID */
   49,  /*     OFFSET => ID */
   49,  /*      RAISE => ID */
   49,  /*    REPLACE => ID */
   49,  /*   RESTRICT => ID */
   49,  /*     RENAME => ID */
   49,  /*   CTIME_KW => ID */
   49,  /*     ENABLE => ID */
   49,  /*    DISABLE => ID */
   49,  /*       UUID => ID */
};
#endif /* YYFALLBACK */

/* The following structure represents a single element of the
** parser's stack.  Information stored includes:
**
**   +  The state number for the parser at this level of the stack.
**
**   +  The value of the token stored at this level of the stack.
**      (In other words, the "major" token.)
**
**   +  The semantic value stored at this level of the stack.  This is
**      the information used by the action routines in the grammar.
**      It is sometimes called the "minor" token.
**
** After the "shift" half of a SHIFTREDUCE action, the stateno field
** actually contains the reduce action for the second half of the
** SHIFTREDUCE.
*/
struct yyStackEntry {
  YYACTIONTYPE stateno;  /* The state-number, or reduce action in SHIFTREDUCE */
  YYCODETYPE major;      /* The major token value.  This is the code
                         ** number for the token at this stack level */
  YYMINORTYPE minor;     /* The user-supplied minor token value.  This
                         ** is the value of the token  */
};
typedef struct yyStackEntry yyStackEntry;

/* The state of the parser is completely contained in an instance of
** the following structure */
struct yyParser {
  yyStackEntry *yytos;          /* Pointer to top element of the stack */
#ifdef YYTRACKMAXSTACKDEPTH
  int yyhwm;                    /* High-water mark of the stack */
#endif
#ifndef YYNOERRORRECOVERY
  int yyerrcnt;                 /* Shifts left before out of the error */
#endif
  bool is_fallback_failed;      /* Shows if fallback failed or not */
  sqlParserARG_SDECL                /* A place to hold %extra_argument */
#if YYSTACKDEPTH<=0
  int yystksz;                  /* Current side of the stack */
  yyStackEntry *yystack;        /* The parser's stack */
  yyStackEntry yystk0;          /* First stack entry */
#else
  yyStackEntry yystack[YYSTACKDEPTH];  /* The parser's stack */
#endif
};
typedef struct yyParser yyParser;

#ifndef NDEBUG
#include <stdio.h>
static FILE *yyTraceFILE = 0;
static char *yyTracePrompt = 0;
#endif /* NDEBUG */

#ifndef NDEBUG
/* 
** Turn parser tracing on by giving a stream to which to write the trace
** and a prompt to preface each trace message.  Tracing is turned off
** by making either argument NULL 
**
** Inputs:
** <ul>
** <li> A FILE* to which trace output should be written.
**      If NULL, then tracing is turned off.
** <li> A prefix string written at the beginning of every
**      line of trace output.  If NULL, then tracing is
**      turned off.
** </ul>
**
** Outputs:
** None.
*/
void sqlParserTrace(FILE *TraceFILE, char *zTracePrompt){
  yyTraceFILE = TraceFILE;
  yyTracePrompt = zTracePrompt;
  if( yyTraceFILE==0 ) yyTracePrompt = 0;
  else if( yyTracePrompt==0 ) yyTraceFILE = 0;
}
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing shifts, the names of all terminals and nonterminals
** are required.  The following table supplies these names */
static const char *const yyTokenName[] = { 
  "$",             "SEMI",          "EXPLAIN",       "QUERY",       
  "PLAN",          "OR",            "AND",           "NOT",         
  "IS",            "MATCH",         "LIKE_KW",       "BETWEEN",     
  "IN",            "NE",            "EQ",            "GT",          
  "LE",            "LT",            "GE",            "ESCAPE",      
  "BITAND",        "BITOR",         "LSHIFT",        "RSHIFT",      
  "PLUS",          "MINUS",         "STAR",          "SLASH",       
  "REM",           "CONCAT",        "COLLATE",       "BITNOT",      
  "START",         "TRANSACTION",   "COMMIT",        "ROLLBACK",    
  "SAVEPOINT",     "RELEASE",       "TO",            "TABLE",       
  "CREATE",        "IF",            "EXISTS",        "LP",          
  "RP",            "WITH",          "ENGINE",        "STRING",      
  "COMMA",         "ID",            "INDEXED",       "ABORT",       
  "ACTION",        "ADD",           "AFTER",         "AUTOINCREMENT",
  "BEFORE",        "CASCADE",       "CONFLICT",      "DEFERRED",    
  "END",           "FAIL",          "IGNORE",        "INITIALLY",   
  "INSTEAD",       "NO",            "KEY",           "OFFSET",      
  "RAISE",         "REPLACE",       "RESTRICT",      "RENAME",      
  "CTIME_KW",      "ENABLE",        "DISABLE",       "UUID",        
  "WILDCARD",      "CONSTRAINT",    "DEFAULT",       "NULL",        
  "PRIMARY",       "UNIQUE",        "CHECK",         "REFERENCES",  
  "AUTOINCR",      "ON",            "UPDATE",        "DELETE",      
  "SIMPLE",        "PARTIAL",       "FULL",          "SET",         
  "DEFERRABLE",    "IMMEDIATE",     "FOREIGN",       "DROP",        
  "VIEW",          "AS",            "UNION",         "ALL",         
  "EXCEPT",        "INTERSECT",     "SELECT",        "VALUES",      
  "DISTINCT",      "DOT",           "FROM",          "JOIN_KW",     
  "JOIN",          "BY",            "USING",         "ORDER",       
  "ASC",           "DESC",          "GROUP",         "HAVING",      
  "LIMIT",         "TRUNCATE",      "WHERE",         "INTO",        
  "INSERT",        "FLOAT",         "BLOB",          "FALSE",       
  "TRUE",          "UNKNOWN",       "DECIMAL",       "INTEGER",     
  "VARIABLE",      "CAST",          "LB",            "RB",          
  "TRIM",          "LEADING",       "TRAILING",      "BOTH",        
  "CHAR",          "CASE",          "WHEN",          "THEN",        
  "ELSE",          "INDEX",         "SESSION",       "PRAGMA",      
  "BEGIN",         "TRIGGER",       "OF",            "FOR",         
  "EACH",          "ROW",           "ALTER",         "COLUMN",      
  "RECURSIVE",     "TEXT",          "STRING_KW",     "SCALAR",      
  "BOOL",          "BOOLEAN",       "VARBINARY",     "ANY",         
  "ARRAY",         "MAP",           "VARCHAR",       "NUMBER",      
  "DOUBLE",        "INT",           "INTEGER_KW",    "UNSIGNED",    
  "error",         "input",         "ecmd",          "explain",     
  "cmdx",          "cmd",           "savepoint_opt",  "nm",          
  "create_table",  "create_table_args",  "with_opts",     "create_table_end",
  "createkw",      "ifnotexists",   "columnlist",    "engine_opts", 
  "tcons",         "column_def",    "create_column_end",  "column_name_and_type",
  "carglist",      "typedef",       "autoinc",       "ccons",       
  "cconsname",     "term",          "expr",          "onconf",      
  "sortorder",     "check_constraint_def",  "eidlist_opt",   "matcharg",    
  "refargs",       "defer_subclause",  "refact_update",  "refact_delete",
  "refact",        "init_deferred_pred_opt",  "col_list_with_autoinc",  "sortlist",    
  "eidlist",       "defer_subclause_opt",  "index_onconf",  "orconf",      
  "resolvetype",   "raisetype",     "ifexists",      "fullname",    
  "select",        "selectnowith",  "oneselect",     "with",        
  "multiselect_op",  "distinct",      "selcollist",    "from",        
  "where_opt",     "groupby_opt",   "having_opt",    "orderby_opt", 
  "limit_opt",     "values",        "nexprlist",     "exprlist",    
  "sclp",          "as",            "seltablist",    "stl_prefix",  
  "joinop",        "indexed_opt",   "on_opt",        "using_opt",   
  "join_nm",       "idlist",        "enable",        "setlist",     
  "insert_cmd",    "idlist_opt",    "trim_operands",  "trim_specification",
  "expr_optional",  "type_func",     "likeop",        "between_op",  
  "in_op",         "paren_exprlist",  "case_exprlist",  "case_else",   
  "uniqueflag",    "trigger_decl",  "trigger_cmd_list",  "trigger_time",
  "trigger_event",  "foreach_clause",  "when_clause",   "trigger_cmd", 
  "trnm",          "tridxby",       "alter_table_start",  "alter_add_constraint",
  "alter_add_column",  "column_name",   "alter_column_def",  "unique_spec", 
  "wqlist",        "char_len",      "number_typedef",
};
#endif /* NDEBUG */

#ifndef NDEBUG
/* For tracing reduce actions, the names of all rules are required.
*/
static const char *const yyRuleName[] = {
 /*   0 */ "ecmd ::= explain cmdx SEMI",
 /*   1 */ "ecmd ::= SEMI",
 /*   2 */ "explain ::= EXPLAIN",
 /*   3 */ "explain ::= EXPLAIN QUERY PLAN",
 /*   4 */ "cmd ::= START TRANSACTION",
 /*   5 */ "cmd ::= COMMIT",
 /*   6 */ "cmd ::= ROLLBACK",
 /*   7 */ "cmd ::= SAVEPOINT nm",
 /*   8 */ "cmd ::= RELEASE savepoint_opt nm",
 /*   9 */ "cmd ::= ROLLBACK TO savepoint_opt nm",
 /*  10 */ "create_table ::= createkw TABLE ifnotexists nm",
 /*  11 */ "createkw ::= CREATE",
 /*  12 */ "ifnotexists ::=",
 /*  13 */ "ifnotexists ::= IF NOT EXISTS",
 /*  14 */ "engine_opts ::= ENGINE EQ STRING",
 /*  15 */ "create_table_end ::=",
 /*  16 */ "column_name_and_type ::= nm typedef",
 /*  17 */ "create_column_end ::= autoinc",
 /*  18 */ "nm ::= ID|INDEXED",
 /*  19 */ "cconsname ::= CONSTRAINT nm",
 /*  20 */ "cconsname ::=",
 /*  21 */ "ccons ::= DEFAULT term",
 /*  22 */ "ccons ::= DEFAULT LP expr RP",
 /*  23 */ "ccons ::= DEFAULT PLUS term",
 /*  24 */ "ccons ::= DEFAULT MINUS term",
 /*  25 */ "ccons ::= NULL onconf",
 /*  26 */ "ccons ::= NOT NULL onconf",
 /*  27 */ "ccons ::= cconsname PRIMARY KEY sortorder",
 /*  28 */ "ccons ::= cconsname UNIQUE",
 /*  29 */ "check_constraint_def ::= cconsname CHECK LP expr RP",
 /*  30 */ "ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs",
 /*  31 */ "ccons ::= defer_subclause",
 /*  32 */ "ccons ::= COLLATE ID|INDEXED",
 /*  33 */ "autoinc ::=",
 /*  34 */ "autoinc ::= AUTOINCR",
 /*  35 */ "refargs ::= refact_update",
 /*  36 */ "refargs ::= refact_delete",
 /*  37 */ "refargs ::= refact_delete refact_update",
 /*  38 */ "refargs ::= refact_update refact_delete",
 /*  39 */ "refargs ::=",
 /*  40 */ "refact_update ::= ON UPDATE refact",
 /*  41 */ "refact_delete ::= ON DELETE refact",
 /*  42 */ "matcharg ::= MATCH SIMPLE",
 /*  43 */ "matcharg ::= MATCH PARTIAL",
 /*  44 */ "matcharg ::= MATCH FULL",
 /*  45 */ "matcharg ::=",
 /*  46 */ "refact ::= SET NULL",
 /*  47 */ "refact ::= SET DEFAULT",
 /*  48 */ "refact ::= CASCADE",
 /*  49 */ "refact ::= RESTRICT",
 /*  50 */ "refact ::= NO ACTION",
 /*  51 */ "defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt",
 /*  52 */ "defer_subclause ::= DEFERRABLE init_deferred_pred_opt",
 /*  53 */ "init_deferred_pred_opt ::=",
 /*  54 */ "init_deferred_pred_opt ::= INITIALLY DEFERRED",
 /*  55 */ "init_deferred_pred_opt ::= INITIALLY IMMEDIATE",
 /*  56 */ "tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP",
 /*  57 */ "tcons ::= cconsname UNIQUE LP sortlist RP",
 /*  58 */ "tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /*  59 */ "defer_subclause_opt ::=",
 /*  60 */ "onconf ::=",
 /*  61 */ "onconf ::= ON CONFLICT resolvetype",
 /*  62 */ "orconf ::=",
 /*  63 */ "orconf ::= OR resolvetype",
 /*  64 */ "resolvetype ::= IGNORE",
 /*  65 */ "resolvetype ::= REPLACE",
 /*  66 */ "cmd ::= DROP TABLE ifexists fullname",
 /*  67 */ "cmd ::= DROP VIEW ifexists fullname",
 /*  68 */ "ifexists ::= IF EXISTS",
 /*  69 */ "ifexists ::=",
 /*  70 */ "cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select",
 /*  71 */ "cmd ::= select",
 /*  72 */ "select ::= with selectnowith",
 /*  73 */ "selectnowith ::= selectnowith multiselect_op oneselect",
 /*  74 */ "multiselect_op ::= UNION",
 /*  75 */ "multiselect_op ::= UNION ALL",
 /*  76 */ "multiselect_op ::= EXCEPT|INTERSECT",
 /*  77 */ "oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt",
 /*  78 */ "values ::= VALUES LP nexprlist RP",
 /*  79 */ "values ::= values COMMA LP exprlist RP",
 /*  80 */ "distinct ::= DISTINCT",
 /*  81 */ "distinct ::= ALL",
 /*  82 */ "distinct ::=",
 /*  83 */ "sclp ::=",
 /*  84 */ "selcollist ::= sclp expr as",
 /*  85 */ "selcollist ::= sclp STAR",
 /*  86 */ "selcollist ::= sclp nm DOT STAR",
 /*  87 */ "as ::= AS nm",
 /*  88 */ "as ::=",
 /*  89 */ "from ::=",
 /*  90 */ "from ::= FROM seltablist",
 /*  91 */ "stl_prefix ::= seltablist joinop",
 /*  92 */ "stl_prefix ::=",
 /*  93 */ "seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt",
 /*  94 */ "seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt",
 /*  95 */ "seltablist ::= stl_prefix LP select RP as on_opt using_opt",
 /*  96 */ "seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt",
 /*  97 */ "fullname ::= nm",
 /*  98 */ "joinop ::= COMMA|JOIN",
 /*  99 */ "joinop ::= JOIN_KW JOIN",
 /* 100 */ "joinop ::= JOIN_KW join_nm JOIN",
 /* 101 */ "joinop ::= JOIN_KW join_nm join_nm JOIN",
 /* 102 */ "on_opt ::= ON expr",
 /* 103 */ "on_opt ::=",
 /* 104 */ "indexed_opt ::=",
 /* 105 */ "indexed_opt ::= INDEXED BY nm",
 /* 106 */ "indexed_opt ::= NOT INDEXED",
 /* 107 */ "using_opt ::= USING LP idlist RP",
 /* 108 */ "using_opt ::=",
 /* 109 */ "orderby_opt ::=",
 /* 110 */ "orderby_opt ::= ORDER BY sortlist",
 /* 111 */ "sortlist ::= sortlist COMMA expr sortorder",
 /* 112 */ "sortlist ::= expr sortorder",
 /* 113 */ "col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc",
 /* 114 */ "col_list_with_autoinc ::= expr autoinc",
 /* 115 */ "enable ::= ENABLE",
 /* 116 */ "enable ::= DISABLE",
 /* 117 */ "sortorder ::= ASC",
 /* 118 */ "sortorder ::= DESC",
 /* 119 */ "sortorder ::=",
 /* 120 */ "groupby_opt ::=",
 /* 121 */ "groupby_opt ::= GROUP BY nexprlist",
 /* 122 */ "having_opt ::=",
 /* 123 */ "having_opt ::= HAVING expr",
 /* 124 */ "limit_opt ::=",
 /* 125 */ "limit_opt ::= LIMIT expr",
 /* 126 */ "limit_opt ::= LIMIT expr OFFSET expr",
 /* 127 */ "limit_opt ::= LIMIT expr COMMA expr",
 /* 128 */ "cmd ::= with DELETE FROM fullname indexed_opt where_opt",
 /* 129 */ "cmd ::= TRUNCATE TABLE fullname",
 /* 130 */ "where_opt ::=",
 /* 131 */ "where_opt ::= WHERE expr",
 /* 132 */ "cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt",
 /* 133 */ "setlist ::= setlist COMMA nm EQ expr",
 /* 134 */ "setlist ::= setlist COMMA LP idlist RP EQ expr",
 /* 135 */ "setlist ::= nm EQ expr",
 /* 136 */ "setlist ::= LP idlist RP EQ expr",
 /* 137 */ "cmd ::= with insert_cmd INTO fullname idlist_opt select",
 /* 138 */ "cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES",
 /* 139 */ "insert_cmd ::= INSERT orconf",
 /* 140 */ "insert_cmd ::= REPLACE",
 /* 141 */ "idlist_opt ::=",
 /* 142 */ "idlist_opt ::= LP idlist RP",
 /* 143 */ "idlist ::= idlist COMMA nm",
 /* 144 */ "idlist ::= nm",
 /* 145 */ "expr ::= LP expr RP",
 /* 146 */ "term ::= NULL",
 /* 147 */ "expr ::= ID|INDEXED",
 /* 148 */ "expr ::= JOIN_KW",
 /* 149 */ "expr ::= nm DOT nm",
 /* 150 */ "term ::= FLOAT|BLOB",
 /* 151 */ "term ::= STRING",
 /* 152 */ "term ::= FALSE",
 /* 153 */ "term ::= TRUE",
 /* 154 */ "term ::= UNKNOWN",
 /* 155 */ "term ::= DECIMAL",
 /* 156 */ "term ::= INTEGER",
 /* 157 */ "expr ::= VARIABLE",
 /* 158 */ "expr ::= expr COLLATE ID|INDEXED",
 /* 159 */ "expr ::= CAST LP expr AS typedef RP",
 /* 160 */ "expr ::= LB exprlist RB",
 /* 161 */ "expr ::= TRIM LP trim_operands RP",
 /* 162 */ "trim_operands ::= trim_specification expr FROM expr",
 /* 163 */ "trim_operands ::= trim_specification FROM expr",
 /* 164 */ "trim_operands ::= expr FROM expr",
 /* 165 */ "trim_operands ::= expr",
 /* 166 */ "expr_optional ::=",
 /* 167 */ "expr_optional ::= expr",
 /* 168 */ "trim_specification ::= LEADING",
 /* 169 */ "trim_specification ::= TRAILING",
 /* 170 */ "trim_specification ::= BOTH",
 /* 171 */ "expr ::= ID|INDEXED LP distinct exprlist RP",
 /* 172 */ "expr ::= type_func LP distinct exprlist RP",
 /* 173 */ "expr ::= ID|INDEXED LP STAR RP",
 /* 174 */ "expr ::= LP nexprlist COMMA expr RP",
 /* 175 */ "expr ::= expr AND expr",
 /* 176 */ "expr ::= expr OR expr",
 /* 177 */ "expr ::= expr LT|GT|GE|LE expr",
 /* 178 */ "expr ::= expr EQ|NE expr",
 /* 179 */ "expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr",
 /* 180 */ "expr ::= expr PLUS|MINUS expr",
 /* 181 */ "expr ::= expr STAR|SLASH|REM expr",
 /* 182 */ "expr ::= expr CONCAT expr",
 /* 183 */ "likeop ::= LIKE_KW|MATCH",
 /* 184 */ "likeop ::= NOT LIKE_KW|MATCH",
 /* 185 */ "expr ::= expr likeop expr",
 /* 186 */ "expr ::= expr likeop expr ESCAPE expr",
 /* 187 */ "expr ::= expr IS NULL",
 /* 188 */ "expr ::= expr IS NOT NULL",
 /* 189 */ "expr ::= NOT expr",
 /* 190 */ "expr ::= BITNOT expr",
 /* 191 */ "expr ::= MINUS expr",
 /* 192 */ "expr ::= PLUS expr",
 /* 193 */ "between_op ::= BETWEEN",
 /* 194 */ "between_op ::= NOT BETWEEN",
 /* 195 */ "expr ::= expr between_op expr AND expr",
 /* 196 */ "in_op ::= IN",
 /* 197 */ "in_op ::= NOT IN",
 /* 198 */ "expr ::= expr in_op LP exprlist RP",
 /* 199 */ "expr ::= LP select RP",
 /* 200 */ "expr ::= expr in_op LP select RP",
 /* 201 */ "expr ::= expr in_op nm paren_exprlist",
 /* 202 */ "expr ::= EXISTS LP select RP",
 /* 203 */ "expr ::= CASE expr_optional case_exprlist case_else END",
 /* 204 */ "case_exprlist ::= case_exprlist WHEN expr THEN expr",
 /* 205 */ "case_exprlist ::= WHEN expr THEN expr",
 /* 206 */ "case_else ::= ELSE expr",
 /* 207 */ "case_else ::=",
 /* 208 */ "exprlist ::=",
 /* 209 */ "nexprlist ::= nexprlist COMMA expr",
 /* 210 */ "nexprlist ::= expr",
 /* 211 */ "paren_exprlist ::=",
 /* 212 */ "paren_exprlist ::= LP exprlist RP",
 /* 213 */ "cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP",
 /* 214 */ "uniqueflag ::= UNIQUE",
 /* 215 */ "uniqueflag ::=",
 /* 216 */ "eidlist_opt ::=",
 /* 217 */ "eidlist_opt ::= LP eidlist RP",
 /* 218 */ "eidlist ::= eidlist COMMA nm",
 /* 219 */ "eidlist ::= nm",
 /* 220 */ "cmd ::= DROP INDEX ifexists nm ON fullname",
 /* 221 */ "cmd ::= SET SESSION nm EQ term",
 /* 222 */ "cmd ::= PRAGMA nm",
 /* 223 */ "cmd ::= PRAGMA nm LP nm RP",
 /* 224 */ "cmd ::= PRAGMA nm LP nm DOT nm RP",
 /* 225 */ "cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END",
 /* 226 */ "trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause",
 /* 227 */ "trigger_time ::= BEFORE",
 /* 228 */ "trigger_time ::= AFTER",
 /* 229 */ "trigger_time ::= INSTEAD OF",
 /* 230 */ "trigger_time ::=",
 /* 231 */ "trigger_event ::= DELETE|INSERT",
 /* 232 */ "trigger_event ::= UPDATE",
 /* 233 */ "trigger_event ::= UPDATE OF idlist",
 /* 234 */ "foreach_clause ::=",
 /* 235 */ "when_clause ::=",
 /* 236 */ "when_clause ::= WHEN expr",
 /* 237 */ "trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI",
 /* 238 */ "trigger_cmd_list ::= trigger_cmd SEMI",
 /* 239 */ "trnm ::= nm DOT nm",
 /* 240 */ "tridxby ::= INDEXED BY nm",
 /* 241 */ "tridxby ::= NOT INDEXED",
 /* 242 */ "trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt",
 /* 243 */ "trigger_cmd ::= insert_cmd INTO trnm idlist_opt select",
 /* 244 */ "trigger_cmd ::= DELETE FROM trnm tridxby where_opt",
 /* 245 */ "trigger_cmd ::= select",
 /* 246 */ "expr ::= RAISE LP IGNORE RP",
 /* 247 */ "expr ::= RAISE LP raisetype COMMA STRING RP",
 /* 248 */ "raisetype ::= ROLLBACK",
 /* 249 */ "raisetype ::= ABORT",
 /* 250 */ "raisetype ::= FAIL",
 /* 251 */ "cmd ::= DROP TRIGGER ifexists fullname",
 /* 252 */ "alter_table_start ::= ALTER TABLE fullname",
 /* 253 */ "alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm",
 /* 254 */ "alter_add_column ::= alter_table_start ADD column_name",
 /* 255 */ "column_name ::= COLUMN nm",
 /* 256 */ "column_name ::= nm",
 /* 257 */ "alter_column_def ::= alter_add_column typedef",
 /* 258 */ "cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt",
 /* 259 */ "cmd ::= alter_add_constraint CHECK LP expr RP",
 /* 260 */ "cmd ::= alter_add_constraint unique_spec LP sortlist RP",
 /* 261 */ "unique_spec ::= UNIQUE",
 /* 262 */ "unique_spec ::= PRIMARY KEY",
 /* 263 */ "cmd ::= alter_table_start RENAME TO nm",
 /* 264 */ "cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm",
 /* 265 */ "cmd ::= alter_table_start enable CHECK CONSTRAINT nm",
 /* 266 */ "with ::=",
 /* 267 */ "with ::= WITH wqlist",
 /* 268 */ "with ::= WITH RECURSIVE wqlist",
 /* 269 */ "wqlist ::= nm eidlist_opt AS LP select RP",
 /* 270 */ "wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP",
 /* 271 */ "typedef ::= TEXT",
 /* 272 */ "typedef ::= STRING_KW",
 /* 273 */ "typedef ::= SCALAR",
 /* 274 */ "typedef ::= BOOL",
 /* 275 */ "typedef ::= BOOLEAN",
 /* 276 */ "typedef ::= VARBINARY",
 /* 277 */ "typedef ::= UUID",
 /* 278 */ "typedef ::= ANY",
 /* 279 */ "typedef ::= ARRAY",
 /* 280 */ "typedef ::= MAP",
 /* 281 */ "char_len ::= LP INTEGER RP",
 /* 282 */ "typedef ::= VARCHAR char_len",
 /* 283 */ "number_typedef ::= NUMBER",
 /* 284 */ "number_typedef ::= DOUBLE",
 /* 285 */ "number_typedef ::= INT|INTEGER_KW",
 /* 286 */ "number_typedef ::= UNSIGNED",
 /* 287 */ "number_typedef ::= DECIMAL",
 /* 288 */ "input ::= ecmd",
 /* 289 */ "explain ::=",
 /* 290 */ "cmdx ::= cmd",
 /* 291 */ "savepoint_opt ::= SAVEPOINT",
 /* 292 */ "savepoint_opt ::=",
 /* 293 */ "cmd ::= create_table create_table_args with_opts create_table_end",
 /* 294 */ "create_table_args ::= LP columnlist RP",
 /* 295 */ "with_opts ::= WITH engine_opts",
 /* 296 */ "with_opts ::=",
 /* 297 */ "columnlist ::= columnlist COMMA tcons",
 /* 298 */ "columnlist ::= columnlist COMMA column_def create_column_end",
 /* 299 */ "columnlist ::= column_def create_column_end",
 /* 300 */ "column_def ::= column_name_and_type carglist",
 /* 301 */ "columnlist ::= tcons",
 /* 302 */ "carglist ::= carglist ccons",
 /* 303 */ "carglist ::=",
 /* 304 */ "ccons ::= check_constraint_def",
 /* 305 */ "tcons ::= check_constraint_def",
 /* 306 */ "defer_subclause_opt ::= defer_subclause",
 /* 307 */ "resolvetype ::= raisetype",
 /* 308 */ "selectnowith ::= oneselect",
 /* 309 */ "oneselect ::= values",
 /* 310 */ "sclp ::= selcollist COMMA",
 /* 311 */ "as ::= ID|STRING",
 /* 312 */ "join_nm ::= ID|INDEXED",
 /* 313 */ "join_nm ::= JOIN_KW",
 /* 314 */ "expr ::= term",
 /* 315 */ "type_func ::= CHAR",
 /* 316 */ "exprlist ::= nexprlist",
 /* 317 */ "foreach_clause ::= FOR EACH ROW",
 /* 318 */ "trnm ::= nm",
 /* 319 */ "tridxby ::=",
 /* 320 */ "cmd ::= alter_column_def carglist create_column_end",
 /* 321 */ "typedef ::= number_typedef",
};
#endif /* NDEBUG */


#if YYSTACKDEPTH<=0
/*
** Try to increase the size of the parser stack.  Return the number
** of errors.  Return 0 on success.
*/
static int yyGrowStack(yyParser *p){
  int newSize;
  int idx;
  yyStackEntry *pNew;

  newSize = p->yystksz*2 + 100;
  idx = p->yytos ? (int)(p->yytos - p->yystack) : 0;
  if( p->yystack==&p->yystk0 ){
    pNew = malloc(newSize*sizeof(pNew[0]));
    if( pNew ) pNew[0] = p->yystk0;
  }else{
    pNew = realloc(p->yystack, newSize*sizeof(pNew[0]));
  }
  if( pNew ){
    p->yystack = pNew;
    p->yytos = &p->yystack[idx];
#ifndef NDEBUG
    if( yyTraceFILE ){
      fprintf(yyTraceFILE,"%sStack grows from %d to %d entries.\n",
              yyTracePrompt, p->yystksz, newSize);
    }
#endif
    p->yystksz = newSize;
  }
  return pNew==0; 
}
#endif

/* Datatype of the argument to the memory allocated passed as the
** second argument to sqlParserAlloc() below.  This can be changed by
** putting an appropriate #define in the %include section of the input
** grammar.
*/
#ifndef YYMALLOCARGTYPE
# define YYMALLOCARGTYPE size_t
#endif

/* 
** This function allocates a new parser.
** The only argument is a pointer to a function which works like
** malloc.
**
** Inputs:
** A pointer to the function used to allocate memory.
**
** Outputs:
** A pointer to a parser.  This pointer is used in subsequent calls
** to sqlParser and sqlParserFree.
*/
void *sqlParserAlloc(void *(*mallocProc)(YYMALLOCARGTYPE)){
  yyParser *pParser;
  pParser = (yyParser*)(*mallocProc)( (YYMALLOCARGTYPE)sizeof(yyParser) );
  if( pParser ){
#ifdef YYTRACKMAXSTACKDEPTH
    pParser->yyhwm = 0;
#endif
    pParser->is_fallback_failed = false;
#if YYSTACKDEPTH<=0
    pParser->yytos = NULL;
    pParser->yystack = NULL;
    pParser->yystksz = 0;
    if( yyGrowStack(pParser) ){
      pParser->yystack = &pParser->yystk0;
      pParser->yystksz = 1;
    }
#endif
#ifndef YYNOERRORRECOVERY
    pParser->yyerrcnt = -1;
#endif
    pParser->yytos = pParser->yystack;
    pParser->yystack[0].stateno = 0;
    pParser->yystack[0].major = 0;
  }
  return pParser;
}

/* The following function deletes the "minor type" or semantic value
** associated with a symbol.  The symbol can be either a terminal
** or nonterminal. "yymajor" is the symbol code, and "yypminor" is
** a pointer to the value to be deleted.  The code used to do the 
** deletions is derived from the %destructor and/or %token_destructor
** directives of the input grammar.
*/
static void yy_destructor(
  yyParser *yypParser,    /* The parser */
  YYCODETYPE yymajor,     /* Type code for object to destroy */
  YYMINORTYPE *yypminor   /* The object to be destroyed */
){
  sqlParserARG_FETCH;
  switch( yymajor ){
    /* Here is inserted the actions which take place when a
    ** terminal or non-terminal is destroyed.  This can happen
    ** when the symbol is popped from the stack during a
    ** reduce or during error processing or when a parser is 
    ** being destroyed before it is finished parsing.
    **
    ** Note: during a reduce, the only symbols destroyed are those
    ** which appear on the RHS of the rule, but which are *not* used
    ** inside the C code.
    */
/********* Begin destructor definitions ***************************************/
    case 193: /* term */
    case 194: /* expr */
{
#line 962 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy192).pExpr, false);
#line 1621 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
    case 198: /* eidlist_opt */
    case 206: /* col_list_with_autoinc */
    case 207: /* sortlist */
    case 208: /* eidlist */
    case 222: /* selcollist */
    case 225: /* groupby_opt */
    case 227: /* orderby_opt */
    case 230: /* nexprlist */
    case 231: /* exprlist */
    case 232: /* sclp */
    case 243: /* setlist */
    case 253: /* paren_exprlist */
    case 254: /* case_exprlist */
{
#line 1536 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy542));
#line 1640 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
    case 215: /* fullname */
    case 223: /* from */
    case 234: /* seltablist */
    case 235: /* stl_prefix */
{
#line 711 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sqlSrcListDelete(pParse->db, (yypminor->yy197));
#line 1650 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
    case 216: /* select */
    case 217: /* selectnowith */
    case 218: /* oneselect */
    case 229: /* values */
{
#line 473 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sql_select_delete(pParse->db, (yypminor->yy509));
#line 1660 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
    case 219: /* with */
    case 272: /* wqlist */
{
#line 1834 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sqlWithDelete(pParse->db, (yypminor->yy81));
#line 1668 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
    case 224: /* where_opt */
    case 226: /* having_opt */
    case 238: /* on_opt */
    case 255: /* case_else */
    case 262: /* when_clause */
{
#line 871 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy22), false);
#line 1679 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
    case 239: /* using_opt */
    case 241: /* idlist */
    case 245: /* idlist_opt */
{
#line 754 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy430));
#line 1688 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
    case 246: /* trim_operands */
{
#line 1151 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sql_expr_list_delete(pParse->db, (yypminor->yy163));
#line 1695 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
    case 248: /* expr_optional */
{
#line 1184 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sql_expr_delete(pParse->db, (yypminor->yy369), false);
#line 1702 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
    case 258: /* trigger_cmd_list */
    case 263: /* trigger_cmd */
{
#line 1635 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sqlDeleteTriggerStep(pParse->db, (yypminor->yy77));
#line 1710 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
    case 260: /* trigger_event */
{
#line 1616 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
sqlIdListDelete(pParse->db, (yypminor->yy510).b);
#line 1717 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
}
      break;
/********* End destructor definitions *****************************************/
    default:  break;   /* If no destructor action specified: do nothing */
  }
}

/*
** Pop the parser's stack once.
**
** If there is a destructor routine associated with the token which
** is popped from the stack, then call it.
*/
static void yy_pop_parser_stack(yyParser *pParser){
  yyStackEntry *yytos;
  assert( pParser->yytos!=0 );
  assert( pParser->yytos > pParser->yystack );
  yytos = pParser->yytos--;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sPopping %s\n",
      yyTracePrompt,
      yyTokenName[yytos->major]);
  }
#endif
  yy_destructor(pParser, yytos->major, &yytos->minor);
}

/* 
** Deallocate and destroy a parser.  Destructors are called for
** all stack elements before shutting the parser down.
**
** If the YYPARSEFREENEVERNULL macro exists (for example because it
** is defined in a %include section of the input grammar) then it is
** assumed that the input pointer is never NULL.
*/
void sqlParserFree(
  void *p,                    /* The parser to be deleted */
  void (*freeProc)(void*)     /* Function used to reclaim memory */
){
  yyParser *pParser = (yyParser*)p;
#ifndef YYPARSEFREENEVERNULL
  if( pParser==0 ) return;
#endif
  while( pParser->yytos>pParser->yystack ) yy_pop_parser_stack(pParser);
#if YYSTACKDEPTH<=0
  if( pParser->yystack!=&pParser->yystk0 ) free(pParser->yystack);
#endif
  (*freeProc)((void*)pParser);
}

/*
** Return the peak depth of the stack for a parser.
*/
#ifdef YYTRACKMAXSTACKDEPTH
int sqlParserStackPeak(void *p){
  yyParser *pParser = (yyParser*)p;
  return pParser->yyhwm;
}
#endif

/*
** Find the appropriate action for a parser given the terminal
** look-ahead token iLookAhead.
*/
static unsigned int yy_find_shift_action(
  yyParser *pParser,        /* The parser */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
  int stateno = pParser->yytos->stateno;
 
  if( stateno>=YY_MIN_REDUCE ) return stateno;
  assert( stateno <= YY_SHIFT_COUNT );
  do{
    i = yy_shift_ofst[stateno];
    assert( iLookAhead!=YYNOCODE );
    i += iLookAhead;
    if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
#ifdef YYFALLBACK
      YYCODETYPE iFallback = -1;            /* Fallback token */
      if( iLookAhead<sizeof(yyFallback)/sizeof(yyFallback[0])
             && (iFallback = yyFallback[iLookAhead])!=0 ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE, "%sFALLBACK %s => %s\n",
             yyTracePrompt, yyTokenName[iLookAhead], yyTokenName[iFallback]);
        }
#endif
        assert( yyFallback[iFallback]==0 ); /* Fallback loop must terminate */
        iLookAhead = iFallback;
        continue;
      } else if ( iFallback==0 ) {
        pParser->is_fallback_failed = true;
      }
#endif
#ifdef YYWILDCARD
      {
        int j = i - iLookAhead + YYWILDCARD;
        if( 
#if YY_SHIFT_MIN+YYWILDCARD<0
          j>=0 &&
#endif
#if YY_SHIFT_MAX+YYWILDCARD>=YY_ACTTAB_COUNT
          j<YY_ACTTAB_COUNT &&
#endif
          yy_lookahead[j]==YYWILDCARD && iLookAhead>0
        ){
#ifndef NDEBUG
          if( yyTraceFILE ){
            fprintf(yyTraceFILE, "%sWILDCARD %s => %s\n",
               yyTracePrompt, yyTokenName[iLookAhead],
               yyTokenName[YYWILDCARD]);
          }
#endif /* NDEBUG */
          return yy_action[j];
        }
      }
#endif /* YYWILDCARD */
      return yy_default[stateno];
    }else{
      return yy_action[i];
    }
  }while(1);
}

/*
** Find the appropriate action for a parser given the non-terminal
** look-ahead token iLookAhead.
*/
static int yy_find_reduce_action(
  int stateno,              /* Current state number */
  YYCODETYPE iLookAhead     /* The look-ahead token */
){
  int i;
#ifdef YYERRORSYMBOL
  if( stateno>YY_REDUCE_COUNT ){
    return yy_default[stateno];
  }
#else
  assert( stateno<=YY_REDUCE_COUNT );
#endif
  i = yy_reduce_ofst[stateno];
  assert( i!=YY_REDUCE_USE_DFLT );
  assert( iLookAhead!=YYNOCODE );
  i += iLookAhead;
#ifdef YYERRORSYMBOL
  if( i<0 || i>=YY_ACTTAB_COUNT || yy_lookahead[i]!=iLookAhead ){
    return yy_default[stateno];
  }
#else
  assert( i>=0 && i<YY_ACTTAB_COUNT );
  assert( yy_lookahead[i]==iLookAhead );
#endif
  return yy_action[i];
}

/*
** The following routine is called if the stack overflows.
*/
static void yyStackOverflow(yyParser *yypParser){
   sqlParserARG_FETCH;
#ifndef NDEBUG
   if( yyTraceFILE ){
     fprintf(yyTraceFILE,"%sStack Overflow!\n",yyTracePrompt);
   }
#endif
   while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
   /* Here code is inserted which will execute if the parser
   ** stack every overflows */
/******** Begin %stack_overflow code ******************************************/
#line 44 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"

  diag_set(ClientError, ER_SQL_STACK_OVERFLOW);
  pParse->is_aborted = true;
#line 1893 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
/******** End %stack_overflow code ********************************************/
   sqlParserARG_STORE; /* Suppress warning about unused %extra_argument var */
}

/*
** Print tracing information for a SHIFT action
*/
#ifndef NDEBUG
static void yyTraceShift(yyParser *yypParser, int yyNewState){
  if( yyTraceFILE ){
    if( yyNewState<YYNSTATE ){
      fprintf(yyTraceFILE,"%sShift '%s', go to state %d\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major],
         yyNewState);
    }else{
      fprintf(yyTraceFILE,"%sShift '%s'\n",
         yyTracePrompt,yyTokenName[yypParser->yytos->major]);
    }
  }
}
#else
# define yyTraceShift(X,Y)
#endif

/*
** Perform a shift action.
*/
static void yy_shift(
  yyParser *yypParser,          /* The parser to be shifted */
  int yyNewState,               /* The new state to shift in */
  int yyMajor,                  /* The major token to shift in */
  sqlParserTOKENTYPE yyMinor        /* The minor token to shift in */
){
  yyStackEntry *yytos;
  yypParser->yytos++;
#ifdef YYTRACKMAXSTACKDEPTH
  if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
    yypParser->yyhwm++;
    assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack) );
  }
#endif
#if YYSTACKDEPTH>0 
  if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH] ){
    yypParser->yytos--;
    yyStackOverflow(yypParser);
    return;
  }
#else
  if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz] ){
    if( yyGrowStack(yypParser) ){
      yypParser->yytos--;
      yyStackOverflow(yypParser);
      return;
    }
  }
#endif
  if( yyNewState > YY_MAX_SHIFT ){
    yyNewState += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
  }
  yytos = yypParser->yytos;
  yytos->stateno = (YYACTIONTYPE)yyNewState;
  yytos->major = (YYCODETYPE)yyMajor;
  yytos->minor.yy0 = yyMinor;
  yyTraceShift(yypParser, yyNewState);
}

/* The following table contains information about every rule that
** is used during the reduce.
*/
static const struct {
  YYCODETYPE lhs;         /* Symbol on the left-hand side of the rule */
  unsigned char nrhs;     /* Number of right-hand side symbols in the rule */
} yyRuleInfo[] = {
  { 170, 3 },
  { 170, 1 },
  { 171, 1 },
  { 171, 3 },
  { 173, 2 },
  { 173, 1 },
  { 173, 1 },
  { 173, 2 },
  { 173, 3 },
  { 173, 4 },
  { 176, 4 },
  { 180, 1 },
  { 181, 0 },
  { 181, 3 },
  { 183, 3 },
  { 179, 0 },
  { 187, 2 },
  { 186, 1 },
  { 175, 1 },
  { 192, 2 },
  { 192, 0 },
  { 191, 2 },
  { 191, 4 },
  { 191, 3 },
  { 191, 3 },
  { 191, 2 },
  { 191, 3 },
  { 191, 4 },
  { 191, 2 },
  { 197, 5 },
  { 191, 6 },
  { 191, 1 },
  { 191, 2 },
  { 190, 0 },
  { 190, 1 },
  { 200, 1 },
  { 200, 1 },
  { 200, 2 },
  { 200, 2 },
  { 200, 0 },
  { 202, 3 },
  { 203, 3 },
  { 199, 2 },
  { 199, 2 },
  { 199, 2 },
  { 199, 0 },
  { 204, 2 },
  { 204, 2 },
  { 204, 1 },
  { 204, 1 },
  { 204, 2 },
  { 201, 3 },
  { 201, 2 },
  { 205, 0 },
  { 205, 2 },
  { 205, 2 },
  { 184, 6 },
  { 184, 5 },
  { 184, 12 },
  { 209, 0 },
  { 195, 0 },
  { 195, 3 },
  { 211, 0 },
  { 211, 2 },
  { 212, 1 },
  { 212, 1 },
  { 173, 4 },
  { 173, 4 },
  { 214, 2 },
  { 214, 0 },
  { 173, 7 },
  { 173, 1 },
  { 216, 2 },
  { 217, 3 },
  { 220, 1 },
  { 220, 2 },
  { 220, 1 },
  { 218, 9 },
  { 229, 4 },
  { 229, 5 },
  { 221, 1 },
  { 221, 1 },
  { 221, 0 },
  { 232, 0 },
  { 222, 3 },
  { 222, 2 },
  { 222, 4 },
  { 233, 2 },
  { 233, 0 },
  { 223, 0 },
  { 223, 2 },
  { 235, 2 },
  { 235, 0 },
  { 234, 6 },
  { 234, 8 },
  { 234, 7 },
  { 234, 7 },
  { 215, 1 },
  { 236, 1 },
  { 236, 2 },
  { 236, 3 },
  { 236, 4 },
  { 238, 2 },
  { 238, 0 },
  { 237, 0 },
  { 237, 3 },
  { 237, 2 },
  { 239, 4 },
  { 239, 0 },
  { 227, 0 },
  { 227, 3 },
  { 207, 4 },
  { 207, 2 },
  { 206, 4 },
  { 206, 2 },
  { 242, 1 },
  { 242, 1 },
  { 196, 1 },
  { 196, 1 },
  { 196, 0 },
  { 225, 0 },
  { 225, 3 },
  { 226, 0 },
  { 226, 2 },
  { 228, 0 },
  { 228, 2 },
  { 228, 4 },
  { 228, 4 },
  { 173, 6 },
  { 173, 3 },
  { 224, 0 },
  { 224, 2 },
  { 173, 8 },
  { 243, 5 },
  { 243, 7 },
  { 243, 3 },
  { 243, 5 },
  { 173, 6 },
  { 173, 7 },
  { 244, 2 },
  { 244, 1 },
  { 245, 0 },
  { 245, 3 },
  { 241, 3 },
  { 241, 1 },
  { 194, 3 },
  { 193, 1 },
  { 194, 1 },
  { 194, 1 },
  { 194, 3 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 193, 1 },
  { 194, 1 },
  { 194, 3 },
  { 194, 6 },
  { 194, 3 },
  { 194, 4 },
  { 246, 4 },
  { 246, 3 },
  { 246, 3 },
  { 246, 1 },
  { 248, 0 },
  { 248, 1 },
  { 247, 1 },
  { 247, 1 },
  { 247, 1 },
  { 194, 5 },
  { 194, 5 },
  { 194, 4 },
  { 194, 5 },
  { 194, 3 },
  { 194, 3 },
  { 194, 3 },
  { 194, 3 },
  { 194, 3 },
  { 194, 3 },
  { 194, 3 },
  { 194, 3 },
  { 250, 1 },
  { 250, 2 },
  { 194, 3 },
  { 194, 5 },
  { 194, 3 },
  { 194, 4 },
  { 194, 2 },
  { 194, 2 },
  { 194, 2 },
  { 194, 2 },
  { 251, 1 },
  { 251, 2 },
  { 194, 5 },
  { 252, 1 },
  { 252, 2 },
  { 194, 5 },
  { 194, 3 },
  { 194, 5 },
  { 194, 4 },
  { 194, 4 },
  { 194, 5 },
  { 254, 5 },
  { 254, 4 },
  { 255, 2 },
  { 255, 0 },
  { 231, 0 },
  { 230, 3 },
  { 230, 1 },
  { 253, 0 },
  { 253, 3 },
  { 173, 10 },
  { 256, 1 },
  { 256, 0 },
  { 198, 0 },
  { 198, 3 },
  { 208, 3 },
  { 208, 1 },
  { 173, 6 },
  { 173, 5 },
  { 173, 2 },
  { 173, 5 },
  { 173, 7 },
  { 173, 5 },
  { 257, 9 },
  { 259, 1 },
  { 259, 1 },
  { 259, 2 },
  { 259, 0 },
  { 260, 1 },
  { 260, 1 },
  { 260, 3 },
  { 261, 0 },
  { 262, 0 },
  { 262, 2 },
  { 258, 3 },
  { 258, 2 },
  { 264, 3 },
  { 265, 3 },
  { 265, 2 },
  { 263, 7 },
  { 263, 5 },
  { 263, 5 },
  { 263, 1 },
  { 194, 4 },
  { 194, 6 },
  { 213, 1 },
  { 213, 1 },
  { 213, 1 },
  { 173, 4 },
  { 266, 3 },
  { 267, 4 },
  { 268, 3 },
  { 269, 2 },
  { 269, 1 },
  { 270, 2 },
  { 173, 12 },
  { 173, 5 },
  { 173, 5 },
  { 271, 1 },
  { 271, 2 },
  { 173, 4 },
  { 173, 6 },
  { 173, 5 },
  { 219, 0 },
  { 219, 2 },
  { 219, 3 },
  { 272, 6 },
  { 272, 8 },
  { 189, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 1 },
  { 189, 1 },
  { 273, 3 },
  { 189, 2 },
  { 274, 1 },
  { 274, 1 },
  { 274, 1 },
  { 274, 1 },
  { 274, 1 },
  { 169, 1 },
  { 171, 0 },
  { 172, 1 },
  { 174, 1 },
  { 174, 0 },
  { 173, 4 },
  { 177, 3 },
  { 178, 2 },
  { 178, 0 },
  { 182, 3 },
  { 182, 4 },
  { 182, 2 },
  { 185, 2 },
  { 182, 1 },
  { 188, 2 },
  { 188, 0 },
  { 191, 1 },
  { 184, 1 },
  { 209, 1 },
  { 212, 1 },
  { 217, 1 },
  { 218, 1 },
  { 232, 2 },
  { 233, 1 },
  { 240, 1 },
  { 240, 1 },
  { 194, 1 },
  { 249, 1 },
  { 231, 1 },
  { 261, 3 },
  { 264, 1 },
  { 265, 0 },
  { 173, 3 },
  { 189, 1 },
};

static void yy_accept(yyParser*);  /* Forward Declaration */

/*
** Perform a reduce action and the shift that must immediately
** follow the reduce.
*/
static void yy_reduce(
  yyParser *yypParser,         /* The parser */
  unsigned int yyruleno        /* Number of the rule by which to reduce */
){
  int yygoto;                     /* The next state */
  int yyact;                      /* The next action */
  yyStackEntry *yymsp;            /* The top of the parser's stack */
  int yysize;                     /* Amount to pop the stack */
  sqlParserARG_FETCH;
  yymsp = yypParser->yytos;
#ifndef NDEBUG
  if( yyTraceFILE && yyruleno<(int)(sizeof(yyRuleName)/sizeof(yyRuleName[0])) ){
    yysize = yyRuleInfo[yyruleno].nrhs;
    fprintf(yyTraceFILE, "%sReduce [%s], go to state %d.\n", yyTracePrompt,
      yyRuleName[yyruleno], yymsp[-yysize].stateno);
  }
#endif /* NDEBUG */

  /* Check that the stack is large enough to grow by a single entry
  ** if the RHS of the rule is empty.  This ensures that there is room
  ** enough on the stack to push the LHS value */
  if( yyRuleInfo[yyruleno].nrhs==0 ){
#ifdef YYTRACKMAXSTACKDEPTH
    if( (int)(yypParser->yytos - yypParser->yystack)>yypParser->yyhwm ){
      yypParser->yyhwm++;
      assert( yypParser->yyhwm == (int)(yypParser->yytos - yypParser->yystack));
    }
#endif
#if YYSTACKDEPTH>0 
    if( yypParser->yytos>=&yypParser->yystack[YYSTACKDEPTH-1] ){
      yyStackOverflow(yypParser);
      return;
    }
#else
    if( yypParser->yytos>=&yypParser->yystack[yypParser->yystksz-1] ){
      if( yyGrowStack(yypParser) ){
        yyStackOverflow(yypParser);
        return;
      }
      yymsp = yypParser->yytos;
    }
#endif
  }

  switch( yyruleno ){
  /* Beginning here are the reduction cases.  A typical example
  ** follows:
  **   case 0:
  **  #line <lineno> <grammarfile>
  **     { ... }           // User supplied code
  **  #line <lineno> <thisfile>
  **     break;
  */
/********** Begin reduce actions **********************************************/
        YYMINORTYPE yylhsminor;
      case 0: /* ecmd ::= explain cmdx SEMI */
#line 123 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
	if (!pParse->parse_only)
		sql_finish_coding(pParse);
}
#line 2358 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 1: /* ecmd ::= SEMI */
#line 127 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_STATEMENT_EMPTY);
  pParse->is_aborted = true;
}
#line 2366 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 2: /* explain ::= EXPLAIN */
#line 132 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ pParse->explain = 1; }
#line 2371 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 3: /* explain ::= EXPLAIN QUERY PLAN */
#line 133 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ pParse->explain = 2; }
#line 2376 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 4: /* cmd ::= START TRANSACTION */
#line 163 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{sql_transaction_begin(pParse);}
#line 2381 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 5: /* cmd ::= COMMIT */
#line 164 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{sql_transaction_commit(pParse);}
#line 2386 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 6: /* cmd ::= ROLLBACK */
#line 165 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{sql_transaction_rollback(pParse);}
#line 2391 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 7: /* cmd ::= SAVEPOINT nm */
#line 169 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_BEGIN, &yymsp[0].minor.yy0);
}
#line 2398 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 8: /* cmd ::= RELEASE savepoint_opt nm */
#line 172 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_RELEASE, &yymsp[0].minor.yy0);
}
#line 2405 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 9: /* cmd ::= ROLLBACK TO savepoint_opt nm */
#line 175 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  sqlSavepoint(pParse, SAVEPOINT_ROLLBACK, &yymsp[0].minor.yy0);
}
#line 2412 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 10: /* create_table ::= createkw TABLE ifnotexists nm */
#line 182 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_table_def_init(&pParse->create_table_def, &yymsp[0].minor.yy0, yymsp[-1].minor.yy42);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  pParse->create_table_def.new_space = sqlStartTable(pParse, &yymsp[0].minor.yy0);
  pParse->initiateTTrans = true;
}
#line 2423 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 11: /* createkw ::= CREATE */
#line 189 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{disableLookaside(pParse);}
#line 2428 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 12: /* ifnotexists ::= */
      case 33: /* autoinc ::= */ yytestcase(yyruleno==33);
      case 53: /* init_deferred_pred_opt ::= */ yytestcase(yyruleno==53);
      case 59: /* defer_subclause_opt ::= */ yytestcase(yyruleno==59);
      case 69: /* ifexists ::= */ yytestcase(yyruleno==69);
      case 82: /* distinct ::= */ yytestcase(yyruleno==82);
#line 192 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy42 = 0;}
#line 2438 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 13: /* ifnotexists ::= IF NOT EXISTS */
#line 193 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-2].minor.yy42 = 1;}
#line 2443 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 14: /* engine_opts ::= ENGINE EQ STRING */
#line 200 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  /* Note that specifying engine clause overwrites default engine. */
  if (yymsp[0].minor.yy0.n > ENGINE_NAME_MAX) {
    diag_set(ClientError, ER_CREATE_SPACE,
             pParse->create_table_def.new_space->def->name,
             "space engine name is too long");
    pParse->is_aborted = true;
    return;
  }
  /* Need to dequote name. */
  char *normalized_name = sql_name_from_token(pParse->db, &yymsp[0].minor.yy0);
  if (normalized_name == NULL)
    return;
  memcpy(pParse->create_table_def.new_space->def->engine_name, normalized_name,
         strlen(normalized_name) + 1);
  sqlDbFree(pParse->db, normalized_name);
}
#line 2464 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 15: /* create_table_end ::= */
#line 218 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ sqlEndTable(pParse); }
#line 2469 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 16: /* column_name_and_type ::= nm typedef */
#line 236 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, NULL, &yymsp[-1].minor.yy0, &yymsp[0].minor.yy320);
  sql_create_column_start(pParse);
}
#line 2477 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 17: /* create_column_end ::= autoinc */
#line 241 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  uint32_t fieldno = pParse->create_column_def.space->def->field_count - 1;
  if (yymsp[0].minor.yy42 == 1 && sql_add_autoincrement(pParse, fieldno) != 0)
    return;
  if (pParse->create_table_def.new_space == NULL)
    sql_create_column_end(pParse);
}
#line 2488 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 18: /* nm ::= ID|INDEXED */
#line 283 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  if(yymsp[0].minor.yy0.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z, yymsp[0].minor.yy0.n, yymsp[0].minor.yy0.z);
    pParse->is_aborted = true;
  }
}
#line 2499 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 19: /* cconsname ::= CONSTRAINT nm */
#line 299 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy237 = yymsp[0].minor.yy0; }
#line 2504 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 20: /* cconsname ::= */
#line 300 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[1].minor.yy237 = Token_nil; }
#line 2509 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 21: /* ccons ::= DEFAULT term */
      case 23: /* ccons ::= DEFAULT PLUS term */ yytestcase(yyruleno==23);
#line 301 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[0].minor.yy192);}
#line 2515 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 22: /* ccons ::= DEFAULT LP expr RP */
#line 302 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{sqlAddDefaultValue(pParse,&yymsp[-1].minor.yy192);}
#line 2520 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 24: /* ccons ::= DEFAULT MINUS term */
#line 304 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  ExprSpan v;
  v.pExpr = sqlPExpr(pParse, TK_UMINUS, yymsp[0].minor.yy192.pExpr, 0);
  v.zStart = yymsp[-1].minor.yy0.z;
  v.zEnd = yymsp[0].minor.yy192.zEnd;
  sqlAddDefaultValue(pParse,&v);
}
#line 2531 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 25: /* ccons ::= NULL onconf */
#line 315 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
    sql_column_add_nullable_action(pParse, ON_CONFLICT_ACTION_NONE);
    /* Trigger nullability mismatch error if required. */
    if (yymsp[0].minor.yy42 != ON_CONFLICT_ACTION_ABORT)
        sql_column_add_nullable_action(pParse, yymsp[0].minor.yy42);
}
#line 2541 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 26: /* ccons ::= NOT NULL onconf */
#line 321 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{sql_column_add_nullable_action(pParse, yymsp[0].minor.yy42);}
#line 2546 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 27: /* ccons ::= cconsname PRIMARY KEY sortorder */
#line 322 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-3].minor.yy237, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, yymsp[0].minor.yy42, false);
  sqlAddPrimaryKey(pParse);
}
#line 2555 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 28: /* ccons ::= cconsname UNIQUE */
#line 327 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-1].minor.yy237, NULL,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2565 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 29: /* check_constraint_def ::= cconsname CHECK LP expr RP */
#line 336 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_ck_def_init(&pParse->create_ck_def, NULL, &yymsp[-4].minor.yy237, &yymsp[-1].minor.yy192);
  sql_create_check_contraint(pParse);
}
#line 2573 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 30: /* ccons ::= cconsname REFERENCES nm eidlist_opt matcharg refargs */
#line 341 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-5].minor.yy237, NULL, &yymsp[-3].minor.yy0, yymsp[-2].minor.yy542, yymsp[-1].minor.yy42, yymsp[0].minor.yy42,
                     false);
  sql_create_foreign_key(pParse);
}
#line 2582 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 31: /* ccons ::= defer_subclause */
#line 346 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{fk_constraint_change_defer_mode(pParse, yymsp[0].minor.yy42);}
#line 2587 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 32: /* ccons ::= COLLATE ID|INDEXED */
#line 347 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{sqlAddCollateType(pParse, &yymsp[0].minor.yy0);}
#line 2592 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 34: /* autoinc ::= AUTOINCR */
#line 352 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = 1;}
#line 2597 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 35: /* refargs ::= refact_update */
#line 360 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yylhsminor.yy42 = (yymsp[0].minor.yy42 << 8); }
#line 2602 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[0].minor.yy42 = yylhsminor.yy42;
        break;
      case 36: /* refargs ::= refact_delete */
#line 361 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yylhsminor.yy42 = yymsp[0].minor.yy42; }
#line 2608 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[0].minor.yy42 = yylhsminor.yy42;
        break;
      case 37: /* refargs ::= refact_delete refact_update */
#line 362 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yylhsminor.yy42 = (yymsp[0].minor.yy42 << 8) | (yymsp[-1].minor.yy42) ; }
#line 2614 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-1].minor.yy42 = yylhsminor.yy42;
        break;
      case 38: /* refargs ::= refact_update refact_delete */
#line 363 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yylhsminor.yy42 = (yymsp[-1].minor.yy42 << 8) | (yymsp[0].minor.yy42) ; }
#line 2620 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-1].minor.yy42 = yylhsminor.yy42;
        break;
      case 39: /* refargs ::= */
#line 364 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[1].minor.yy42 = 0; }
#line 2626 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 40: /* refact_update ::= ON UPDATE refact */
      case 41: /* refact_delete ::= ON DELETE refact */ yytestcase(yyruleno==41);
#line 367 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-2].minor.yy42 = yymsp[0].minor.yy42; }
#line 2632 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 42: /* matcharg ::= MATCH SIMPLE */
#line 372 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy42 = FKEY_MATCH_SIMPLE; }
#line 2637 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 43: /* matcharg ::= MATCH PARTIAL */
#line 373 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy42 = FKEY_MATCH_PARTIAL; }
#line 2642 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 44: /* matcharg ::= MATCH FULL */
#line 374 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy42 = FKEY_MATCH_FULL; }
#line 2647 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 45: /* matcharg ::= */
#line 375 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[1].minor.yy42 = FKEY_MATCH_SIMPLE; }
#line 2652 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 46: /* refact ::= SET NULL */
#line 378 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy42 = FKEY_ACTION_SET_NULL; }
#line 2657 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 47: /* refact ::= SET DEFAULT */
#line 379 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy42 = FKEY_ACTION_SET_DEFAULT; }
#line 2662 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 48: /* refact ::= CASCADE */
#line 380 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy42 = FKEY_ACTION_CASCADE; }
#line 2667 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 49: /* refact ::= RESTRICT */
#line 381 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy42 = FKEY_ACTION_RESTRICT; }
#line 2672 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 50: /* refact ::= NO ACTION */
#line 382 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy42 = FKEY_NO_ACTION; }
#line 2677 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 51: /* defer_subclause ::= NOT DEFERRABLE init_deferred_pred_opt */
#line 384 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-2].minor.yy42 = 0;}
#line 2682 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 52: /* defer_subclause ::= DEFERRABLE init_deferred_pred_opt */
      case 63: /* orconf ::= OR resolvetype */ yytestcase(yyruleno==63);
      case 139: /* insert_cmd ::= INSERT orconf */ yytestcase(yyruleno==139);
#line 385 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-1].minor.yy42 = yymsp[0].minor.yy42;}
#line 2689 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 54: /* init_deferred_pred_opt ::= INITIALLY DEFERRED */
      case 68: /* ifexists ::= IF EXISTS */ yytestcase(yyruleno==68);
      case 194: /* between_op ::= NOT BETWEEN */ yytestcase(yyruleno==194);
      case 197: /* in_op ::= NOT IN */ yytestcase(yyruleno==197);
#line 388 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-1].minor.yy42 = 1;}
#line 2697 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 55: /* init_deferred_pred_opt ::= INITIALLY IMMEDIATE */
#line 389 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-1].minor.yy42 = 0;}
#line 2702 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 56: /* tcons ::= cconsname PRIMARY KEY LP col_list_with_autoinc RP */
#line 391 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-5].minor.yy237, yymsp[-1].minor.yy542,
                        SQL_INDEX_TYPE_CONSTRAINT_PK, SORT_ORDER_ASC, false);
  sqlAddPrimaryKey(pParse);
}
#line 2711 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 57: /* tcons ::= cconsname UNIQUE LP sortlist RP */
#line 396 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, NULL, &yymsp[-4].minor.yy237, yymsp[-1].minor.yy542,
                        SQL_INDEX_TYPE_CONSTRAINT_UNIQUE, SORT_ORDER_ASC,
                        false);
  sql_create_index(pParse);
}
#line 2721 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 58: /* tcons ::= cconsname FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 404 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, NULL, &yymsp[-11].minor.yy237, yymsp[-7].minor.yy542, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy542, yymsp[-2].minor.yy42, yymsp[-1].minor.yy42, yymsp[0].minor.yy42);
  sql_create_foreign_key(pParse);
}
#line 2729 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 60: /* onconf ::= */
#line 419 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy42 = ON_CONFLICT_ACTION_ABORT;}
#line 2734 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 61: /* onconf ::= ON CONFLICT resolvetype */
#line 420 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-2].minor.yy42 = yymsp[0].minor.yy42;}
#line 2739 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 62: /* orconf ::= */
#line 421 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy42 = ON_CONFLICT_ACTION_DEFAULT;}
#line 2744 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 64: /* resolvetype ::= IGNORE */
#line 424 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = ON_CONFLICT_ACTION_IGNORE;}
#line 2749 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 65: /* resolvetype ::= REPLACE */
      case 140: /* insert_cmd ::= REPLACE */ yytestcase(yyruleno==140);
#line 425 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = ON_CONFLICT_ACTION_REPLACE;}
#line 2755 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 66: /* cmd ::= DROP TABLE ifexists fullname */
#line 430 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_table_def_init(&pParse->drop_table_def, yymsp[0].minor.yy197, &t, yymsp[-1].minor.yy42);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2765 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 67: /* cmd ::= DROP VIEW ifexists fullname */
#line 437 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_view_def_init(&pParse->drop_view_def, yymsp[0].minor.yy197, &t, yymsp[-1].minor.yy42);
  pParse->initiateTTrans = true;
  sql_drop_table(pParse);
}
#line 2775 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 70: /* cmd ::= createkw VIEW ifnotexists nm eidlist_opt AS select */
#line 451 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  if (!pParse->parse_only) {
    create_view_def_init(&pParse->create_view_def, &yymsp[-3].minor.yy0, &yymsp[-6].minor.yy0, yymsp[-2].minor.yy542, yymsp[0].minor.yy509, yymsp[-4].minor.yy42);
    pParse->initiateTTrans = true;
    sql_create_view(pParse);
  } else {
    sql_store_select(pParse, yymsp[0].minor.yy509);
  }
}
#line 2788 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 71: /* cmd ::= select */
#line 463 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  SelectDest dest = {SRT_Output, 0, 0, 0, 0, 0, 0};
  if(!pParse->parse_only)
          sqlSelect(pParse, yymsp[0].minor.yy509, &dest);
  else
          sql_expr_extract_select(pParse, yymsp[0].minor.yy509);
  sql_select_delete(pParse->db, yymsp[0].minor.yy509);
}
#line 2800 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 72: /* select ::= with selectnowith */
#line 506 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  Select *p = yymsp[0].minor.yy509;
  if( p ){
    p->pWith = yymsp[-1].minor.yy81;
    parserDoubleLinkSelect(pParse, p);
  }else{
    sqlWithDelete(pParse->db, yymsp[-1].minor.yy81);
  }
  yymsp[-1].minor.yy509 = p; /*A-overwrites-W*/
}
#line 2814 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 73: /* selectnowith ::= selectnowith multiselect_op oneselect */
#line 519 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  Select *pRhs = yymsp[0].minor.yy509;
  Select *pLhs = yymsp[-2].minor.yy509;
  if( pRhs && pRhs->pPrior ){
    SrcList *pFrom;
    Token x;
    x.n = 0;
    parserDoubleLinkSelect(pParse, pRhs);
    pFrom = sqlSrcListAppendFromTerm(pParse,0,0,&x,pRhs,0,0);
    pRhs = sqlSelectNew(pParse,0,pFrom,0,0,0,0,0,0,0);
  }
  if( pRhs ){
    pRhs->op = (u8)yymsp[-1].minor.yy42;
    pRhs->pPrior = pLhs;
    if( ALWAYS(pLhs) ) pLhs->selFlags &= ~SF_MultiValue;
    pRhs->selFlags &= ~SF_MultiValue;
    if( yymsp[-1].minor.yy42!=TK_ALL ) pParse->hasCompound = 1;
  }else{
    sql_select_delete(pParse->db, pLhs);
  }
  yymsp[-2].minor.yy509 = pRhs;
}
#line 2840 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 74: /* multiselect_op ::= UNION */
      case 76: /* multiselect_op ::= EXCEPT|INTERSECT */ yytestcase(yyruleno==76);
#line 542 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = yymsp[0].major; /*A-overwrites-OP*/}
#line 2846 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 75: /* multiselect_op ::= UNION ALL */
#line 543 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-1].minor.yy42 = TK_ALL;}
#line 2851 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 77: /* oneselect ::= SELECT distinct selcollist from where_opt groupby_opt having_opt orderby_opt limit_opt */
#line 547 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
#ifdef SQL_DEBUG
  Token s = yymsp[-8].minor.yy0; /*A-overwrites-S*/
#endif
  if (yymsp[0].minor.yy14.pLimit != NULL)
    sql_expr_check_sort_orders(pParse, yymsp[-1].minor.yy542);
  yymsp[-8].minor.yy509 = sqlSelectNew(pParse,yymsp[-6].minor.yy542,yymsp[-5].minor.yy197,yymsp[-4].minor.yy22,yymsp[-3].minor.yy542,yymsp[-2].minor.yy22,yymsp[-1].minor.yy542,yymsp[-7].minor.yy42,yymsp[0].minor.yy14.pLimit,yymsp[0].minor.yy14.pOffset);
#ifdef SQL_DEBUG
  /* Populate the Select.zSelName[] string that is used to help with
  ** query planner debugging, to differentiate between multiple Select
  ** objects in a complex query.
  **
  ** If the SELECT keyword is immediately followed by a C-style comment
  ** then extract the first few alphanumeric characters from within that
  ** comment to be the zSelName value.  Otherwise, the label is #N where
  ** is an integer that is incremented with each SELECT statement seen.
  */
  if( yymsp[-8].minor.yy509!=0 ){
    const char *z = s.z+6;
    int i;
    sql_snprintf(sizeof(yymsp[-8].minor.yy509->zSelName), yymsp[-8].minor.yy509->zSelName, "#%d",
                     ++pParse->nSelect);
    while( z[0]==' ' ) z++;
    if( z[0]=='/' && z[1]=='*' ){
      z += 2;
      while( z[0]==' ' ) z++;
      for(i=0; sqlIsalnum(z[i]); i++){}
      sql_snprintf(sizeof(yymsp[-8].minor.yy509->zSelName), yymsp[-8].minor.yy509->zSelName, "%.*s", i, z);
    }
  }
#endif /* SQL_DEBUG */
}
#line 2887 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 78: /* values ::= VALUES LP nexprlist RP */
#line 583 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy509 = sqlSelectNew(pParse,yymsp[-1].minor.yy542,0,0,0,0,0,SF_Values,0,0);
}
#line 2894 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 79: /* values ::= values COMMA LP exprlist RP */
#line 586 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  Select *pRight, *pLeft = yymsp[-4].minor.yy509;
  pRight = sqlSelectNew(pParse,yymsp[-1].minor.yy542,0,0,0,0,0,SF_Values|SF_MultiValue,0,0);
  if( ALWAYS(pLeft) ) pLeft->selFlags &= ~SF_MultiValue;
  if( pRight ){
    pRight->op = TK_ALL;
    pRight->pPrior = pLeft;
    yymsp[-4].minor.yy509 = pRight;
  }else{
    yymsp[-4].minor.yy509 = pLeft;
  }
}
#line 2910 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 80: /* distinct ::= DISTINCT */
#line 603 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = SF_Distinct;}
#line 2915 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 81: /* distinct ::= ALL */
#line 604 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = SF_All;}
#line 2920 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 83: /* sclp ::= */
      case 109: /* orderby_opt ::= */ yytestcase(yyruleno==109);
      case 120: /* groupby_opt ::= */ yytestcase(yyruleno==120);
      case 208: /* exprlist ::= */ yytestcase(yyruleno==208);
      case 211: /* paren_exprlist ::= */ yytestcase(yyruleno==211);
      case 216: /* eidlist_opt ::= */ yytestcase(yyruleno==216);
#line 617 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy542 = 0;}
#line 2930 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 84: /* selcollist ::= sclp expr as */
#line 618 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
   yymsp[-2].minor.yy542 = sql_expr_list_append(pParse->db, yymsp[-2].minor.yy542, yymsp[-1].minor.yy192.pExpr);
   if( yymsp[0].minor.yy0.n>0 ) sqlExprListSetName(pParse, yymsp[-2].minor.yy542, &yymsp[0].minor.yy0, 1);
   sqlExprListSetSpan(pParse,yymsp[-2].minor.yy542,&yymsp[-1].minor.yy192);
}
#line 2939 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 85: /* selcollist ::= sclp STAR */
#line 623 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  struct Expr *p = sql_expr_new_anon(pParse->db, TK_ASTERISK);
  if (p == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-1].minor.yy542 = sql_expr_list_append(pParse->db, yymsp[-1].minor.yy542, p);
}
#line 2951 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 86: /* selcollist ::= sclp nm DOT STAR */
#line 631 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  struct Expr *pLeft = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (pLeft == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Expr *pRight = sqlPExpr(pParse, TK_ASTERISK, 0, 0);
  Expr *pDot = sqlPExpr(pParse, TK_DOT, pLeft, pRight);
  yymsp[-3].minor.yy542 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy542, pDot);
}
#line 2965 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 87: /* as ::= AS nm */
#line 646 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-1].minor.yy0 = yymsp[0].minor.yy0;}
#line 2970 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 88: /* as ::= */
#line 648 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy0.n = 0; yymsp[1].minor.yy0.z = 0;}
#line 2975 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 89: /* from ::= */
#line 660 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy197 = sqlDbMallocZero(pParse->db, sizeof(*yymsp[1].minor.yy197));}
#line 2980 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 90: /* from ::= FROM seltablist */
#line 661 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy197 = yymsp[0].minor.yy197;
  sqlSrcListShiftJoinType(yymsp[-1].minor.yy197);
}
#line 2988 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 91: /* stl_prefix ::= seltablist joinop */
#line 669 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
   if( ALWAYS(yymsp[-1].minor.yy197 && yymsp[-1].minor.yy197->nSrc>0) ) yymsp[-1].minor.yy197->a[yymsp[-1].minor.yy197->nSrc-1].fg.jointype = (u8)yymsp[0].minor.yy42;
}
#line 2995 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 92: /* stl_prefix ::= */
#line 672 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy197 = 0;}
#line 3000 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 93: /* seltablist ::= stl_prefix nm as indexed_opt on_opt using_opt */
#line 674 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy197 = sqlSrcListAppendFromTerm(pParse,yymsp[-5].minor.yy197,&yymsp[-4].minor.yy0,&yymsp[-3].minor.yy0,0,yymsp[-1].minor.yy22,yymsp[0].minor.yy430);
  sqlSrcListIndexedBy(pParse, yymsp[-5].minor.yy197, &yymsp[-2].minor.yy0);
}
#line 3008 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 94: /* seltablist ::= stl_prefix nm LP exprlist RP as on_opt using_opt */
#line 679 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy197 = sqlSrcListAppendFromTerm(pParse,yymsp[-7].minor.yy197,&yymsp[-6].minor.yy0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy22,yymsp[0].minor.yy430);
  sqlSrcListFuncArgs(pParse, yymsp[-7].minor.yy197, yymsp[-4].minor.yy542);
}
#line 3016 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 95: /* seltablist ::= stl_prefix LP select RP as on_opt using_opt */
#line 684 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy197 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy197,0,&yymsp[-2].minor.yy0,yymsp[-4].minor.yy509,yymsp[-1].minor.yy22,yymsp[0].minor.yy430);
}
#line 3023 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 96: /* seltablist ::= stl_prefix LP seltablist RP as on_opt using_opt */
#line 688 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  if( yymsp[-6].minor.yy197==0 && yymsp[-2].minor.yy0.n==0 && yymsp[-1].minor.yy22==0 && yymsp[0].minor.yy430==0 ){
    yymsp[-6].minor.yy197 = yymsp[-4].minor.yy197;
  }else if( yymsp[-4].minor.yy197->nSrc==1 ){
    yymsp[-6].minor.yy197 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy197,0,&yymsp[-2].minor.yy0,0,yymsp[-1].minor.yy22,yymsp[0].minor.yy430);
    if( yymsp[-6].minor.yy197 ){
      struct SrcList_item *pNew = &yymsp[-6].minor.yy197->a[yymsp[-6].minor.yy197->nSrc-1];
      struct SrcList_item *pOld = yymsp[-4].minor.yy197->a;
      pNew->zName = pOld->zName;
      pNew->pSelect = pOld->pSelect;
      pOld->zName =  0;
      pOld->pSelect = 0;
    }
    sqlSrcListDelete(pParse->db, yymsp[-4].minor.yy197);
  }else{
    Select *pSubquery;
    sqlSrcListShiftJoinType(yymsp[-4].minor.yy197);
    pSubquery = sqlSelectNew(pParse,0,yymsp[-4].minor.yy197,0,0,0,0,SF_NestedFrom,0,0);
    yymsp[-6].minor.yy197 = sqlSrcListAppendFromTerm(pParse,yymsp[-6].minor.yy197,0,&yymsp[-2].minor.yy0,pSubquery,yymsp[-1].minor.yy22,yymsp[0].minor.yy430);
  }
}
#line 3048 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 97: /* fullname ::= nm */
#line 712 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  /* yylhsminor.yy197-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy197 = sql_src_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy197 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3060 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[0].minor.yy197 = yylhsminor.yy197;
        break;
      case 98: /* joinop ::= COMMA|JOIN */
#line 725 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy42 = JT_INNER; }
#line 3066 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 99: /* joinop ::= JOIN_KW JOIN */
#line 727 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-1].minor.yy42 = sqlJoinType(pParse,&yymsp[-1].minor.yy0,0,0);  /*X-overwrites-A*/}
#line 3071 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 100: /* joinop ::= JOIN_KW join_nm JOIN */
#line 729 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-2].minor.yy42 = sqlJoinType(pParse,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0,0); /*X-overwrites-A*/}
#line 3076 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 101: /* joinop ::= JOIN_KW join_nm join_nm JOIN */
#line 731 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-3].minor.yy42 = sqlJoinType(pParse,&yymsp[-3].minor.yy0,&yymsp[-2].minor.yy0,&yymsp[-1].minor.yy0);/*X-overwrites-A*/}
#line 3081 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 102: /* on_opt ::= ON expr */
      case 123: /* having_opt ::= HAVING expr */ yytestcase(yyruleno==123);
      case 131: /* where_opt ::= WHERE expr */ yytestcase(yyruleno==131);
      case 206: /* case_else ::= ELSE expr */ yytestcase(yyruleno==206);
#line 735 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-1].minor.yy22 = yymsp[0].minor.yy192.pExpr;}
#line 3089 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 103: /* on_opt ::= */
      case 122: /* having_opt ::= */ yytestcase(yyruleno==122);
      case 130: /* where_opt ::= */ yytestcase(yyruleno==130);
      case 207: /* case_else ::= */ yytestcase(yyruleno==207);
#line 736 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy22 = 0;}
#line 3097 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 104: /* indexed_opt ::= */
#line 749 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy0.z=0; yymsp[1].minor.yy0.n=0;}
#line 3102 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 105: /* indexed_opt ::= INDEXED BY nm */
#line 750 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;}
#line 3107 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 106: /* indexed_opt ::= NOT INDEXED */
#line 751 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-1].minor.yy0.z=0; yymsp[-1].minor.yy0.n=1;}
#line 3112 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 107: /* using_opt ::= USING LP idlist RP */
#line 755 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-3].minor.yy430 = yymsp[-1].minor.yy430;}
#line 3117 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 108: /* using_opt ::= */
      case 141: /* idlist_opt ::= */ yytestcase(yyruleno==141);
#line 756 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy430 = 0;}
#line 3123 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 110: /* orderby_opt ::= ORDER BY sortlist */
      case 121: /* groupby_opt ::= GROUP BY nexprlist */ yytestcase(yyruleno==121);
#line 770 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-2].minor.yy542 = yymsp[0].minor.yy542;}
#line 3129 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 111: /* sortlist ::= sortlist COMMA expr sortorder */
#line 771 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy542 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy542,yymsp[-1].minor.yy192.pExpr);
  sqlExprListSetSortOrder(yymsp[-3].minor.yy542,yymsp[0].minor.yy42);
}
#line 3137 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 112: /* sortlist ::= expr sortorder */
#line 775 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  /* yylhsminor.yy542-overwrites-yymsp[-1].minor.yy192. */
  yylhsminor.yy542 = sql_expr_list_append(pParse->db,NULL,yymsp[-1].minor.yy192.pExpr);
  sqlExprListSetSortOrder(yylhsminor.yy542,yymsp[0].minor.yy42);
}
#line 3146 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-1].minor.yy542 = yylhsminor.yy542;
        break;
      case 113: /* col_list_with_autoinc ::= col_list_with_autoinc COMMA expr autoinc */
#line 789 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  uint32_t fieldno;
  if (yymsp[0].minor.yy42 == 1) {
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy192.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  yymsp[-3].minor.yy542 = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy542, yymsp[-1].minor.yy192.pExpr);
}
#line 3161 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 114: /* col_list_with_autoinc ::= expr autoinc */
#line 800 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  if (yymsp[0].minor.yy42 == 1) {
    uint32_t fieldno = 0;
    if (sql_fieldno_by_name(pParse, yymsp[-1].minor.yy192.pExpr, &fieldno) != 0)
      return;
    if (sql_add_autoincrement(pParse, fieldno) != 0)
      return;
  }
  /* yylhsminor.yy542-overwrites-yymsp[-1].minor.yy192. */
  yylhsminor.yy542 = sql_expr_list_append(pParse->db, NULL, yymsp[-1].minor.yy192.pExpr);
}
#line 3176 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-1].minor.yy542 = yylhsminor.yy542;
        break;
      case 115: /* enable ::= ENABLE */
#line 813 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy537 = true;}
#line 3182 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 116: /* enable ::= DISABLE */
#line 814 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy537 = false;}
#line 3187 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 117: /* sortorder ::= ASC */
#line 818 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = SORT_ORDER_ASC;}
#line 3192 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 118: /* sortorder ::= DESC */
#line 819 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = SORT_ORDER_DESC;}
#line 3197 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 119: /* sortorder ::= */
#line 820 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy42 = SORT_ORDER_UNDEF;}
#line 3202 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 124: /* limit_opt ::= */
#line 845 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy14.pLimit = 0; yymsp[1].minor.yy14.pOffset = 0;}
#line 3207 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 125: /* limit_opt ::= LIMIT expr */
#line 846 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-1].minor.yy14.pLimit = yymsp[0].minor.yy192.pExpr; yymsp[-1].minor.yy14.pOffset = 0;}
#line 3212 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 126: /* limit_opt ::= LIMIT expr OFFSET expr */
#line 848 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-3].minor.yy14.pLimit = yymsp[-2].minor.yy192.pExpr; yymsp[-3].minor.yy14.pOffset = yymsp[0].minor.yy192.pExpr;}
#line 3217 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 127: /* limit_opt ::= LIMIT expr COMMA expr */
#line 850 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-3].minor.yy14.pOffset = yymsp[-2].minor.yy192.pExpr; yymsp[-3].minor.yy14.pLimit = yymsp[0].minor.yy192.pExpr;}
#line 3222 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 128: /* cmd ::= with DELETE FROM fullname indexed_opt where_opt */
#line 854 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy81, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-2].minor.yy197, &yymsp[-1].minor.yy0);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sql_table_delete_from(pParse,yymsp[-2].minor.yy197,yymsp[0].minor.yy22);
}
#line 3234 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 129: /* cmd ::= TRUNCATE TABLE fullname */
#line 865 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  pParse->initiateTTrans = true;
  sql_table_truncate(pParse, yymsp[0].minor.yy197);
}
#line 3242 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 132: /* cmd ::= with UPDATE orconf fullname indexed_opt SET setlist where_opt */
#line 879 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-7].minor.yy81, 1);
  sqlSrcListIndexedBy(pParse, yymsp[-4].minor.yy197, &yymsp[-3].minor.yy0);
  if (yymsp[-1].minor.yy542 != NULL && yymsp[-1].minor.yy542->nExpr > pParse->db->aLimit[SQL_LIMIT_COLUMN]) {
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, "The number of columns in set "\
             "list", yymsp[-1].minor.yy542->nExpr, pParse->db->aLimit[SQL_LIMIT_COLUMN]);
    pParse->is_aborted = true;
  }
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlUpdate(pParse,yymsp[-4].minor.yy197,yymsp[-1].minor.yy542,yymsp[0].minor.yy22,yymsp[-5].minor.yy42);
}
#line 3259 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 133: /* setlist ::= setlist COMMA nm EQ expr */
#line 896 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy542 = sql_expr_list_append(pParse->db, yymsp[-4].minor.yy542, yymsp[0].minor.yy192.pExpr);
  sqlExprListSetName(pParse, yymsp[-4].minor.yy542, &yymsp[-2].minor.yy0, 1);
}
#line 3267 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 134: /* setlist ::= setlist COMMA LP idlist RP EQ expr */
#line 900 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-6].minor.yy542 = sqlExprListAppendVector(pParse, yymsp[-6].minor.yy542, yymsp[-3].minor.yy430, yymsp[0].minor.yy192.pExpr);
}
#line 3274 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 135: /* setlist ::= nm EQ expr */
#line 903 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yylhsminor.yy542 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy192.pExpr);
  sqlExprListSetName(pParse, yylhsminor.yy542, &yymsp[-2].minor.yy0, 1);
}
#line 3282 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-2].minor.yy542 = yylhsminor.yy542;
        break;
      case 136: /* setlist ::= LP idlist RP EQ expr */
#line 907 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy542 = sqlExprListAppendVector(pParse, 0, yymsp[-3].minor.yy430, yymsp[0].minor.yy192.pExpr);
}
#line 3290 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 137: /* cmd ::= with insert_cmd INTO fullname idlist_opt select */
#line 913 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-5].minor.yy81, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-2].minor.yy197, yymsp[0].minor.yy509, yymsp[-1].minor.yy430, yymsp[-4].minor.yy42);
}
#line 3301 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 138: /* cmd ::= with insert_cmd INTO fullname idlist_opt DEFAULT VALUES */
#line 921 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  sqlWithPush(pParse, yymsp[-6].minor.yy81, 1);
  sqlSubProgramsRemaining = SQL_MAX_COMPILING_TRIGGERS;
  /* Instruct SQL to initate Tarantool's transaction.  */
  pParse->initiateTTrans = true;
  sqlInsert(pParse, yymsp[-3].minor.yy197, 0, yymsp[-2].minor.yy430, yymsp[-5].minor.yy42);
}
#line 3312 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 142: /* idlist_opt ::= LP idlist RP */
#line 939 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-2].minor.yy430 = yymsp[-1].minor.yy430;}
#line 3317 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 143: /* idlist ::= idlist COMMA nm */
#line 940 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy430 = sql_id_list_append(pParse->db,yymsp[-2].minor.yy430,&yymsp[0].minor.yy0);
  if (yymsp[-2].minor.yy430 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3328 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 144: /* idlist ::= nm */
#line 947 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  /* yylhsminor.yy430-overwrites-yymsp[0].minor.yy0. */
  yylhsminor.yy430 = sql_id_list_append(pParse->db,0,&yymsp[0].minor.yy0);
  if (yylhsminor.yy430 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 3340 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[0].minor.yy430 = yylhsminor.yy430;
        break;
      case 145: /* expr ::= LP expr RP */
#line 1053 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{spanSet(&yymsp[-2].minor.yy192,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/  yymsp[-2].minor.yy192.pExpr = yymsp[-1].minor.yy192.pExpr;}
#line 3346 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 146: /* term ::= NULL */
      case 150: /* term ::= FLOAT|BLOB */ yytestcase(yyruleno==150);
      case 151: /* term ::= STRING */ yytestcase(yyruleno==151);
      case 152: /* term ::= FALSE */ yytestcase(yyruleno==152);
      case 153: /* term ::= TRUE */ yytestcase(yyruleno==153);
      case 154: /* term ::= UNKNOWN */ yytestcase(yyruleno==154);
      case 155: /* term ::= DECIMAL */ yytestcase(yyruleno==155);
#line 1054 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy192,pParse,yymsp[0].major,yymsp[0].minor.yy0);/*A-overwrites-X*/}
#line 3357 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 147: /* expr ::= ID|INDEXED */
      case 148: /* expr ::= JOIN_KW */ yytestcase(yyruleno==148);
#line 1055 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{spanExpr(&yymsp[0].minor.yy192,pParse,TK_ID,yymsp[0].minor.yy0); /*A-overwrites-X*/}
#line 3363 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 149: /* expr ::= nm DOT nm */
#line 1057 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  struct Expr *temp1 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[-2].minor.yy0);
  if (temp1 == NULL) {
    pParse->is_aborted = true;
    return;
  }
  struct Expr *temp2 = sql_expr_new_dequoted(pParse->db, TK_ID, &yymsp[0].minor.yy0);
  if (temp2 == NULL) {
    sql_expr_delete(pParse->db, temp1, false);
    pParse->is_aborted = true;
    return;
  }
  spanSet(&yymsp[-2].minor.yy192,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-2].minor.yy192.pExpr = sqlPExpr(pParse, TK_DOT, temp1, temp2);
}
#line 3382 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 156: /* term ::= INTEGER */
#line 1079 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yylhsminor.yy192.pExpr = sql_expr_new_dequoted(pParse->db, TK_INTEGER, &yymsp[0].minor.yy0);
  if (yylhsminor.yy192.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yylhsminor.yy192.pExpr->type = FIELD_TYPE_INTEGER;
  yylhsminor.yy192.zStart = yymsp[0].minor.yy0.z;
  yylhsminor.yy192.zEnd = yymsp[0].minor.yy0.z + yymsp[0].minor.yy0.n;
  if( yylhsminor.yy192.pExpr ) yylhsminor.yy192.pExpr->flags |= EP_Leaf;
}
#line 3397 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[0].minor.yy192 = yylhsminor.yy192;
        break;
      case 157: /* expr ::= VARIABLE */
#line 1090 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  Token t = yymsp[0].minor.yy0;
  if (pParse->parse_only) {
    spanSet(&yylhsminor.yy192, &t, &t);
    diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
             pParse->line_pos, "bindings are not allowed in DDL");
    pParse->is_aborted = true;
    yylhsminor.yy192.pExpr = NULL;
  } else if (!(yymsp[0].minor.yy0.z[0]=='#' && sqlIsdigit(yymsp[0].minor.yy0.z[1]))) {
    u32 n = yymsp[0].minor.yy0.n;
    spanExpr(&yylhsminor.yy192, pParse, TK_VARIABLE, yymsp[0].minor.yy0);
    if (yylhsminor.yy192.pExpr->u.zToken[0] == '?' && n > 1) {
      diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
      pParse->is_aborted = true;
    } else {
      sqlExprAssignVarNumber(pParse, yylhsminor.yy192.pExpr, n);
    }
  }else{
    assert( t.n>=2 );
    spanSet(&yylhsminor.yy192, &t, &t);
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, t.n, t.z);
    pParse->is_aborted = true;
    yylhsminor.yy192.pExpr = NULL;
  }
}
#line 3427 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[0].minor.yy192 = yylhsminor.yy192;
        break;
      case 158: /* expr ::= expr COLLATE ID|INDEXED */
#line 1115 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy192.pExpr = sqlExprAddCollateToken(pParse, yymsp[-2].minor.yy192.pExpr, &yymsp[0].minor.yy0, 1);
  yymsp[-2].minor.yy192.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3436 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 159: /* expr ::= CAST LP expr AS typedef RP */
#line 1120 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy192,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-X*/
  yymsp[-5].minor.yy192.pExpr = sql_expr_new_dequoted(pParse->db, TK_CAST, NULL);
  if (yymsp[-5].minor.yy192.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy192.pExpr->type = yymsp[-1].minor.yy320.type;
  sqlExprAttachSubtrees(pParse->db, yymsp[-5].minor.yy192.pExpr, yymsp[-3].minor.yy192.pExpr, 0);
}
#line 3450 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 160: /* expr ::= LB exprlist RB */
#line 1131 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  struct Expr *expr = sql_expr_new_anon(pParse->db, TK_ARRAY);
  if (expr == NULL) {
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy542);
    pParse->is_aborted = true;
    return;
  }
  expr->x.pList = yymsp[-1].minor.yy542;
  expr->type = FIELD_TYPE_ARRAY;
  sqlExprSetHeightAndFlags(pParse, expr);
  yylhsminor.yy192.pExpr = expr;
  spanSet(&yylhsminor.yy192, &yymsp[-2].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3467 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-2].minor.yy192 = yylhsminor.yy192;
        break;
      case 161: /* expr ::= TRIM LP trim_operands RP */
#line 1145 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yylhsminor.yy192.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy163, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy192, &yymsp[-3].minor.yy0, &yymsp[0].minor.yy0);
}
#line 3476 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-3].minor.yy192 = yylhsminor.yy192;
        break;
      case 162: /* trim_operands ::= trim_specification expr FROM expr */
#line 1153 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yylhsminor.yy163 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy192.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-3].minor.yy445]);
  yylhsminor.yy163 = sql_expr_list_append(pParse->db, yylhsminor.yy163, p);
  yylhsminor.yy163 = sql_expr_list_append(pParse->db, yylhsminor.yy163, yymsp[-2].minor.yy192.pExpr);
}
#line 3488 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-3].minor.yy163 = yylhsminor.yy163;
        break;
      case 163: /* trim_operands ::= trim_specification FROM expr */
#line 1161 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yylhsminor.yy163 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy192.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[yymsp[-2].minor.yy445]);
  yylhsminor.yy163 = sql_expr_list_append(pParse->db, yylhsminor.yy163, p);
}
#line 3499 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-2].minor.yy163 = yylhsminor.yy163;
        break;
      case 164: /* trim_operands ::= expr FROM expr */
#line 1168 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yylhsminor.yy163 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy192.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[TRIM_BOTH]);
  yylhsminor.yy163 = sql_expr_list_append(pParse->db, yylhsminor.yy163, p);
  yylhsminor.yy163 = sql_expr_list_append(pParse->db, yylhsminor.yy163, yymsp[-2].minor.yy192.pExpr);
}
#line 3511 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-2].minor.yy163 = yylhsminor.yy163;
        break;
      case 165: /* trim_operands ::= expr */
#line 1176 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yylhsminor.yy163 = sql_expr_list_append(pParse->db, NULL, yymsp[0].minor.yy192.pExpr);
  struct Expr *p = sql_expr_new_dequoted(pParse->db, TK_INTEGER,
                                         &sqlIntTokens[TRIM_BOTH]);
  yylhsminor.yy163 = sql_expr_list_append(pParse->db, yylhsminor.yy163, p);
}
#line 3522 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[0].minor.yy163 = yylhsminor.yy163;
        break;
      case 166: /* expr_optional ::= */
#line 1186 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[1].minor.yy369 = NULL; }
#line 3528 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 167: /* expr_optional ::= expr */
#line 1187 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yylhsminor.yy369 = yymsp[0].minor.yy192.pExpr; }
#line 3533 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[0].minor.yy369 = yylhsminor.yy369;
        break;
      case 168: /* trim_specification ::= LEADING */
#line 1191 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy445 = TRIM_LEADING; }
#line 3539 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 169: /* trim_specification ::= TRAILING */
#line 1192 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy445 = TRIM_TRAILING; }
#line 3544 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 170: /* trim_specification ::= BOTH */
#line 1193 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy445 = TRIM_BOTH; }
#line 3549 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 171: /* expr ::= ID|INDEXED LP distinct exprlist RP */
      case 172: /* expr ::= type_func LP distinct exprlist RP */ yytestcase(yyruleno==172);
#line 1195 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy542 && yymsp[-1].minor.yy542->nExpr>pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG] ){
    const char *err =
      tt_sprintf("Number of arguments to function %.*s", yymsp[-4].minor.yy0.n, yymsp[-4].minor.yy0.z);
    diag_set(ClientError, ER_SQL_PARSER_LIMIT, err, yymsp[-1].minor.yy542->nExpr,
             pParse->db->aLimit[SQL_LIMIT_FUNCTION_ARG]);
    pParse->is_aborted = true;
  }
  yylhsminor.yy192.pExpr = sqlExprFunction(pParse, yymsp[-1].minor.yy542, &yymsp[-4].minor.yy0);
  spanSet(&yylhsminor.yy192,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);
  if( yymsp[-2].minor.yy42==SF_Distinct && yylhsminor.yy192.pExpr ){
    yylhsminor.yy192.pExpr->flags |= EP_Distinct;
  }
}
#line 3568 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-4].minor.yy192 = yylhsminor.yy192;
        break;
      case 173: /* expr ::= ID|INDEXED LP STAR RP */
#line 1230 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yylhsminor.yy192.pExpr = sqlExprFunction(pParse, 0, &yymsp[-3].minor.yy0);
  spanSet(&yylhsminor.yy192,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);
}
#line 3577 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-3].minor.yy192 = yylhsminor.yy192;
        break;
      case 174: /* expr ::= LP nexprlist COMMA expr RP */
#line 1265 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db, yymsp[-3].minor.yy542, yymsp[-1].minor.yy192.pExpr);
  yylhsminor.yy192.pExpr = sqlPExpr(pParse, TK_VECTOR, 0, 0);
  if( yylhsminor.yy192.pExpr ){
    yylhsminor.yy192.pExpr->x.pList = pList;
    spanSet(&yylhsminor.yy192, &yymsp[-4].minor.yy0, &yymsp[0].minor.yy0);
  }else{
    sql_expr_list_delete(pParse->db, pList);
  }
}
#line 3592 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-4].minor.yy192 = yylhsminor.yy192;
        break;
      case 175: /* expr ::= expr AND expr */
      case 176: /* expr ::= expr OR expr */ yytestcase(yyruleno==176);
      case 177: /* expr ::= expr LT|GT|GE|LE expr */ yytestcase(yyruleno==177);
      case 178: /* expr ::= expr EQ|NE expr */ yytestcase(yyruleno==178);
      case 179: /* expr ::= expr BITAND|BITOR|LSHIFT|RSHIFT expr */ yytestcase(yyruleno==179);
      case 180: /* expr ::= expr PLUS|MINUS expr */ yytestcase(yyruleno==180);
      case 181: /* expr ::= expr STAR|SLASH|REM expr */ yytestcase(yyruleno==181);
      case 182: /* expr ::= expr CONCAT expr */ yytestcase(yyruleno==182);
#line 1276 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{spanBinaryExpr(pParse,yymsp[-1].major,&yymsp[-2].minor.yy192,&yymsp[0].minor.yy192);}
#line 3605 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 183: /* likeop ::= LIKE_KW|MATCH */
#line 1289 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy0=yymsp[0].minor.yy0;/*A-overwrites-X*/}
#line 3610 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 184: /* likeop ::= NOT LIKE_KW|MATCH */
#line 1290 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-1].minor.yy0=yymsp[0].minor.yy0; yymsp[-1].minor.yy0.n|=0x80000000; /*yymsp[-1].minor.yy0-overwrite-yymsp[0].minor.yy0*/}
#line 3615 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 185: /* expr ::= expr likeop expr */
#line 1291 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-1].minor.yy0.n & 0x80000000;
  yymsp[-1].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[0].minor.yy192.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-2].minor.yy192.pExpr);
  yymsp[-2].minor.yy192.pExpr = sqlExprFunction(pParse, pList, &yymsp[-1].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-2].minor.yy192);
  yymsp[-2].minor.yy192.zEnd = yymsp[0].minor.yy192.zEnd;
  if( yymsp[-2].minor.yy192.pExpr ) yymsp[-2].minor.yy192.pExpr->flags |= EP_InfixFunc;
}
#line 3630 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 186: /* expr ::= expr likeop expr ESCAPE expr */
#line 1302 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  ExprList *pList;
  int bNot = yymsp[-3].minor.yy0.n & 0x80000000;
  yymsp[-3].minor.yy0.n &= 0x7fffffff;
  pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy192.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[-4].minor.yy192.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy192.pExpr);
  yymsp[-4].minor.yy192.pExpr = sqlExprFunction(pParse, pList, &yymsp[-3].minor.yy0);
  exprNot(pParse, bNot, &yymsp[-4].minor.yy192);
  yymsp[-4].minor.yy192.zEnd = yymsp[0].minor.yy192.zEnd;
  if( yymsp[-4].minor.yy192.pExpr ) yymsp[-4].minor.yy192.pExpr->flags |= EP_InfixFunc;
}
#line 3646 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 187: /* expr ::= expr IS NULL */
#line 1332 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_ISNULL,&yymsp[-2].minor.yy192,&yymsp[0].minor.yy0);}
#line 3651 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 188: /* expr ::= expr IS NOT NULL */
#line 1333 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{spanUnaryPostfix(pParse,TK_NOTNULL,&yymsp[-3].minor.yy192,&yymsp[0].minor.yy0);}
#line 3656 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 189: /* expr ::= NOT expr */
      case 190: /* expr ::= BITNOT expr */ yytestcase(yyruleno==190);
#line 1355 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy192,pParse,yymsp[-1].major,&yymsp[0].minor.yy192,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3662 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 191: /* expr ::= MINUS expr */
#line 1359 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy192,pParse,TK_UMINUS,&yymsp[0].minor.yy192,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3667 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 192: /* expr ::= PLUS expr */
#line 1361 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{spanUnaryPrefix(&yymsp[-1].minor.yy192,pParse,TK_UPLUS,&yymsp[0].minor.yy192,&yymsp[-1].minor.yy0);/*A-overwrites-B*/}
#line 3672 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 193: /* between_op ::= BETWEEN */
      case 196: /* in_op ::= IN */ yytestcase(yyruleno==196);
#line 1364 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = 0;}
#line 3678 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 195: /* expr ::= expr between_op expr AND expr */
#line 1366 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  ExprList *pList = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy192.pExpr);
  pList = sql_expr_list_append(pParse->db,pList, yymsp[0].minor.yy192.pExpr);
  yymsp[-4].minor.yy192.pExpr = sqlPExpr(pParse, TK_BETWEEN, yymsp[-4].minor.yy192.pExpr, 0);
  if( yymsp[-4].minor.yy192.pExpr ){
    yymsp[-4].minor.yy192.pExpr->x.pList = pList;
  }else{
    sql_expr_list_delete(pParse->db, pList);
  } 
  exprNot(pParse, yymsp[-3].minor.yy42, &yymsp[-4].minor.yy192);
  yymsp[-4].minor.yy192.zEnd = yymsp[0].minor.yy192.zEnd;
}
#line 3694 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 198: /* expr ::= expr in_op LP exprlist RP */
#line 1381 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  if( yymsp[-1].minor.yy542==0 ){
    /* Expressions of the form
    **
    **      expr1 IN ()
    **      expr1 NOT IN ()
    **
    ** simplify to constants 0 (false) and 1 (true), respectively,
    ** regardless of the value of expr1.
    */
    sql_expr_delete(pParse->db, yymsp[-4].minor.yy192.pExpr, false);
    int tk = yymsp[-3].minor.yy42 == 0 ? TK_FALSE : TK_TRUE;
    yymsp[-4].minor.yy192.pExpr = sql_expr_new_anon(pParse->db, tk);
    if (yymsp[-4].minor.yy192.pExpr == NULL) {
      pParse->is_aborted = true;
      return;
    }
    yymsp[-4].minor.yy192.pExpr->type = FIELD_TYPE_BOOLEAN;
  }else if( yymsp[-1].minor.yy542->nExpr==1 ){
    /* Expressions of the form:
    **
    **      expr1 IN (?1)
    **      expr1 NOT IN (?2)
    **
    ** with exactly one value on the RHS can be simplified to something
    ** like this:
    **
    **      expr1 == ?1
    **      expr1 <> ?2
    */
    Expr *pRHS = yymsp[-1].minor.yy542->a[0].pExpr;
    yymsp[-1].minor.yy542->a[0].pExpr = 0;
    sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy542);
    yymsp[-4].minor.yy192.pExpr = sqlPExpr(pParse, yymsp[-3].minor.yy42 ? TK_NE : TK_EQ, yymsp[-4].minor.yy192.pExpr, pRHS);
  }else{
    yymsp[-4].minor.yy192.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy192.pExpr, 0);
    if( yymsp[-4].minor.yy192.pExpr ){
      yymsp[-4].minor.yy192.pExpr->x.pList = yymsp[-1].minor.yy542;
      sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy192.pExpr);
    }else{
      sql_expr_list_delete(pParse->db, yymsp[-1].minor.yy542);
    }
    exprNot(pParse, yymsp[-3].minor.yy42, &yymsp[-4].minor.yy192);
  }
  yymsp[-4].minor.yy192.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3744 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 199: /* expr ::= LP select RP */
#line 1427 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  spanSet(&yymsp[-2].minor.yy192,&yymsp[-2].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  yymsp[-2].minor.yy192.pExpr = sqlPExpr(pParse, TK_SELECT, 0, 0);
  sqlPExprAddSelect(pParse, yymsp[-2].minor.yy192.pExpr, yymsp[-1].minor.yy509);
}
#line 3753 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 200: /* expr ::= expr in_op LP select RP */
#line 1432 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy192.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-4].minor.yy192.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-4].minor.yy192.pExpr, yymsp[-1].minor.yy509);
  exprNot(pParse, yymsp[-3].minor.yy42, &yymsp[-4].minor.yy192);
  yymsp[-4].minor.yy192.zEnd = &yymsp[0].minor.yy0.z[yymsp[0].minor.yy0.n];
}
#line 3763 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 201: /* expr ::= expr in_op nm paren_exprlist */
#line 1438 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  struct SrcList *pSrc = sql_src_list_append(pParse->db, 0,&yymsp[-1].minor.yy0);
  if (pSrc == NULL) {
    pParse->is_aborted = true;
    return;
  }
  Select *pSelect = sqlSelectNew(pParse, 0,pSrc,0,0,0,0,0,0,0);
  if( yymsp[0].minor.yy542 )  sqlSrcListFuncArgs(pParse, pSelect ? pSrc : 0, yymsp[0].minor.yy542);
  yymsp[-3].minor.yy192.pExpr = sqlPExpr(pParse, TK_IN, yymsp[-3].minor.yy192.pExpr, 0);
  sqlPExprAddSelect(pParse, yymsp[-3].minor.yy192.pExpr, pSelect);
  exprNot(pParse, yymsp[-2].minor.yy42, &yymsp[-3].minor.yy192);
  yymsp[-3].minor.yy192.zEnd = &yymsp[-1].minor.yy0.z[yymsp[-1].minor.yy0.n];
}
#line 3780 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 202: /* expr ::= EXISTS LP select RP */
#line 1451 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  Expr *p;
  spanSet(&yymsp[-3].minor.yy192,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0); /*A-overwrites-B*/
  p = yymsp[-3].minor.yy192.pExpr = sqlPExpr(pParse, TK_EXISTS, 0, 0);
  sqlPExprAddSelect(pParse, p, yymsp[-1].minor.yy509);
}
#line 3790 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 203: /* expr ::= CASE expr_optional case_exprlist case_else END */
#line 1459 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  spanSet(&yymsp[-4].minor.yy192,&yymsp[-4].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-C*/
  yymsp[-4].minor.yy192.pExpr = sqlPExpr(pParse, TK_CASE, yymsp[-3].minor.yy369, 0);
  if( yymsp[-4].minor.yy192.pExpr ){
    yymsp[-4].minor.yy192.pExpr->x.pList = yymsp[-1].minor.yy22 ? sql_expr_list_append(pParse->db,yymsp[-2].minor.yy542,yymsp[-1].minor.yy22) : yymsp[-2].minor.yy542;
    sqlExprSetHeightAndFlags(pParse, yymsp[-4].minor.yy192.pExpr);
  }else{
    sql_expr_list_delete(pParse->db, yymsp[-2].minor.yy542);
    sql_expr_delete(pParse->db, yymsp[-1].minor.yy22, false);
  }
}
#line 3805 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 204: /* case_exprlist ::= case_exprlist WHEN expr THEN expr */
#line 1472 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy542 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy542, yymsp[-2].minor.yy192.pExpr);
  yymsp[-4].minor.yy542 = sql_expr_list_append(pParse->db,yymsp[-4].minor.yy542, yymsp[0].minor.yy192.pExpr);
}
#line 3813 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 205: /* case_exprlist ::= WHEN expr THEN expr */
#line 1476 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-3].minor.yy542 = sql_expr_list_append(pParse->db,NULL, yymsp[-2].minor.yy192.pExpr);
  yymsp[-3].minor.yy542 = sql_expr_list_append(pParse->db,yymsp[-3].minor.yy542, yymsp[0].minor.yy192.pExpr);
}
#line 3821 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 209: /* nexprlist ::= nexprlist COMMA expr */
#line 1493 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-2].minor.yy542 = sql_expr_list_append(pParse->db,yymsp[-2].minor.yy542,yymsp[0].minor.yy192.pExpr);}
#line 3826 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 210: /* nexprlist ::= expr */
#line 1495 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy542 = sql_expr_list_append(pParse->db,NULL,yymsp[0].minor.yy192.pExpr); /*A-overwrites-Y*/}
#line 3831 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 212: /* paren_exprlist ::= LP exprlist RP */
      case 217: /* eidlist_opt ::= LP eidlist RP */ yytestcase(yyruleno==217);
#line 1502 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-2].minor.yy542 = yymsp[-1].minor.yy542;}
#line 3837 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 213: /* cmd ::= createkw uniqueflag INDEX ifnotexists nm ON nm LP sortlist RP */
#line 1508 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  struct SrcList *src_list = sql_src_list_append(pParse->db,0,&yymsp[-3].minor.yy0);
  if (src_list == NULL) {
    pParse->is_aborted = true;
    return;
  }
  create_index_def_init(&pParse->create_index_def, src_list, &yymsp[-5].minor.yy0, yymsp[-1].minor.yy542, yymsp[-8].minor.yy42,
                        SORT_ORDER_ASC, yymsp[-6].minor.yy42);
  pParse->initiateTTrans = true;
  sql_create_index(pParse);
}
#line 3852 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 214: /* uniqueflag ::= UNIQUE */
#line 1521 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = SQL_INDEX_TYPE_UNIQUE;}
#line 3857 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 215: /* uniqueflag ::= */
#line 1522 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy42 = SQL_INDEX_TYPE_NON_UNIQUE;}
#line 3862 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 218: /* eidlist ::= eidlist COMMA nm */
#line 1557 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy542 = parserAddExprIdListTerm(pParse, yymsp[-2].minor.yy542, &yymsp[0].minor.yy0);
}
#line 3869 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 219: /* eidlist ::= nm */
#line 1560 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[0].minor.yy542 = parserAddExprIdListTerm(pParse, 0, &yymsp[0].minor.yy0); /*A-overwrites-Y*/
}
#line 3876 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 220: /* cmd ::= DROP INDEX ifexists nm ON fullname */
#line 1567 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  drop_index_def_init(&pParse->drop_index_def, yymsp[0].minor.yy197, &yymsp[-2].minor.yy0, yymsp[-3].minor.yy42);
  pParse->initiateTTrans = true;
  sql_drop_index(pParse);
}
#line 3885 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 221: /* cmd ::= SET SESSION nm EQ term */
#line 1575 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
    sql_setting_set(pParse,&yymsp[-2].minor.yy0,yymsp[0].minor.yy192.pExpr);
}
#line 3892 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 222: /* cmd ::= PRAGMA nm */
#line 1581 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[0].minor.yy0,0,0);
}
#line 3899 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 223: /* cmd ::= PRAGMA nm LP nm RP */
#line 1584 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-3].minor.yy0,&yymsp[-1].minor.yy0,0);
}
#line 3906 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 224: /* cmd ::= PRAGMA nm LP nm DOT nm RP */
#line 1587 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
    sqlPragma(pParse,&yymsp[-5].minor.yy0,&yymsp[-1].minor.yy0,&yymsp[-3].minor.yy0);
}
#line 3913 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 225: /* cmd ::= createkw trigger_decl BEGIN trigger_cmd_list END */
#line 1592 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  Token all;
  all.z = yymsp[-3].minor.yy0.z;
  all.n = (int)(yymsp[0].minor.yy0.z - yymsp[-3].minor.yy0.z) + yymsp[0].minor.yy0.n;
  pParse->initiateTTrans = true;
  sql_trigger_finish(pParse, yymsp[-1].minor.yy77, &all);
}
#line 3924 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 226: /* trigger_decl ::= TRIGGER ifnotexists nm trigger_time trigger_event ON fullname foreach_clause when_clause */
#line 1602 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_trigger_def_init(&pParse->create_trigger_def, yymsp[-2].minor.yy197, &yymsp[-6].minor.yy0, yymsp[-5].minor.yy42, yymsp[-4].minor.yy510.a, yymsp[-4].minor.yy510.b, yymsp[0].minor.yy22,
                          yymsp[-7].minor.yy42);
  sql_trigger_begin(pParse);
  yymsp[-8].minor.yy0 = yymsp[-6].minor.yy0; /*yymsp[-8].minor.yy0-overwrites-T*/
}
#line 3934 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 227: /* trigger_time ::= BEFORE */
#line 1610 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy42 = TK_BEFORE; }
#line 3939 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 228: /* trigger_time ::= AFTER */
#line 1611 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy42 = TK_AFTER;  }
#line 3944 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 229: /* trigger_time ::= INSTEAD OF */
#line 1612 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy42 = TK_INSTEAD;}
#line 3949 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 230: /* trigger_time ::= */
#line 1613 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[1].minor.yy42 = TK_BEFORE; }
#line 3954 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 231: /* trigger_event ::= DELETE|INSERT */
      case 232: /* trigger_event ::= UPDATE */ yytestcase(yyruleno==232);
#line 1617 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy510.a = yymsp[0].major; /*A-overwrites-X*/ yymsp[0].minor.yy510.b = 0;}
#line 3960 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 233: /* trigger_event ::= UPDATE OF idlist */
#line 1619 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[-2].minor.yy510.a = TK_UPDATE; yymsp[-2].minor.yy510.b = yymsp[0].minor.yy430;}
#line 3965 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 234: /* foreach_clause ::= */
#line 1621 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "FOR EACH STATEMENT triggers are not implemented, "
           "please supply FOR EACH ROW clause");
  pParse->is_aborted = true;
}
#line 3975 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 235: /* when_clause ::= */
#line 1631 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[1].minor.yy22 = 0; }
#line 3980 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 236: /* when_clause ::= WHEN expr */
#line 1632 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy22 = yymsp[0].minor.yy192.pExpr; }
#line 3985 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 237: /* trigger_cmd_list ::= trigger_cmd_list trigger_cmd SEMI */
#line 1636 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  assert( yymsp[-2].minor.yy77!=0 );
  yymsp[-2].minor.yy77->pLast->pNext = yymsp[-1].minor.yy77;
  yymsp[-2].minor.yy77->pLast = yymsp[-1].minor.yy77;
}
#line 3994 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 238: /* trigger_cmd_list ::= trigger_cmd SEMI */
#line 1641 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ 
  assert( yymsp[-1].minor.yy77!=0 );
  yymsp[-1].minor.yy77->pLast = yymsp[-1].minor.yy77;
}
#line 4002 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 239: /* trnm ::= nm DOT nm */
#line 1652 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-2].minor.yy0 = yymsp[0].minor.yy0;
  diag_set(ClientError, ER_SQL_PARSER_GENERIC_WITH_POS, pParse->line_count,
           pParse->line_pos, "qualified table names are not allowed on INSERT, "
           "UPDATE, and DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 4013 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 240: /* tridxby ::= INDEXED BY nm */
#line 1665 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the INDEXED BY clause is not allowed on UPDATE "\
           "or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 4023 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 241: /* tridxby ::= NOT INDEXED */
#line 1671 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  diag_set(ClientError, ER_SQL_SYNTAX_WITH_POS, pParse->line_count,
           pParse->line_pos, "the NOT INDEXED BY clause is not allowed on "\
           "UPDATE or DELETE statements within triggers");
  pParse->is_aborted = true;
}
#line 4033 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 242: /* trigger_cmd ::= UPDATE orconf trnm tridxby SET setlist where_opt */
#line 1684 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
     yymsp[-6].minor.yy77 = sql_trigger_update_step(pParse->db, &yymsp[-4].minor.yy0, yymsp[-1].minor.yy542, yymsp[0].minor.yy22, yymsp[-5].minor.yy42);
     if (yymsp[-6].minor.yy77 == NULL) {
        pParse->is_aborted = true;
        return;
     }
   }
#line 4044 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 243: /* trigger_cmd ::= insert_cmd INTO trnm idlist_opt select */
#line 1693 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  /*yylhsminor.yy77-overwrites-yymsp[-4].minor.yy42. */
  yylhsminor.yy77 = sql_trigger_insert_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[-1].minor.yy430, yymsp[0].minor.yy509, yymsp[-4].minor.yy42);
  if (yylhsminor.yy77 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4056 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-4].minor.yy77 = yylhsminor.yy77;
        break;
      case 244: /* trigger_cmd ::= DELETE FROM trnm tridxby where_opt */
#line 1703 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-4].minor.yy77 = sql_trigger_delete_step(pParse->db, &yymsp[-2].minor.yy0, yymsp[0].minor.yy22);
  if (yymsp[-4].minor.yy77 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4068 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 245: /* trigger_cmd ::= select */
#line 1712 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  /* yylhsminor.yy77-overwrites-yymsp[0].minor.yy509. */
  yylhsminor.yy77 = sql_trigger_select_step(pParse->db, yymsp[0].minor.yy509);
  if (yylhsminor.yy77 == NULL) {
    pParse->is_aborted = true;
    return;
  }
}
#line 4080 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[0].minor.yy77 = yylhsminor.yy77;
        break;
      case 246: /* expr ::= RAISE LP IGNORE RP */
#line 1722 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  spanSet(&yymsp[-3].minor.yy192,&yymsp[-3].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-3].minor.yy192.pExpr = sqlPExpr(pParse, TK_RAISE, 0, 0);
  if( yymsp[-3].minor.yy192.pExpr ){
    yymsp[-3].minor.yy192.pExpr->on_conflict_action = ON_CONFLICT_ACTION_IGNORE;
  }
}
#line 4092 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 247: /* expr ::= RAISE LP raisetype COMMA STRING RP */
#line 1729 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  spanSet(&yymsp[-5].minor.yy192,&yymsp[-5].minor.yy0,&yymsp[0].minor.yy0);  /*A-overwrites-X*/
  yymsp[-5].minor.yy192.pExpr = sql_expr_new_dequoted(pParse->db, TK_RAISE, &yymsp[-1].minor.yy0);
  if(yymsp[-5].minor.yy192.pExpr == NULL) {
    pParse->is_aborted = true;
    return;
  }
  yymsp[-5].minor.yy192.pExpr->on_conflict_action = (enum on_conflict_action) yymsp[-3].minor.yy42;
}
#line 4105 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 248: /* raisetype ::= ROLLBACK */
#line 1740 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = ON_CONFLICT_ACTION_ROLLBACK;}
#line 4110 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 249: /* raisetype ::= ABORT */
#line 1741 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = ON_CONFLICT_ACTION_ABORT;}
#line 4115 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 250: /* raisetype ::= FAIL */
#line 1742 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[0].minor.yy42 = ON_CONFLICT_ACTION_FAIL;}
#line 4120 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 251: /* cmd ::= DROP TRIGGER ifexists fullname */
#line 1746 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  struct Token t = Token_nil;
  drop_trigger_def_init(&pParse->drop_trigger_def, yymsp[0].minor.yy197, &t, yymsp[-1].minor.yy42);
  pParse->initiateTTrans = true;
  sql_drop_trigger(pParse);
}
#line 4130 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 252: /* alter_table_start ::= ALTER TABLE fullname */
#line 1763 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-2].minor.yy458 = yymsp[0].minor.yy197; }
#line 4135 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 253: /* alter_add_constraint ::= alter_table_start ADD CONSTRAINT nm */
#line 1766 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
   yylhsminor.yy90.table_name = yymsp[-3].minor.yy458;
   yylhsminor.yy90.name = yymsp[0].minor.yy0;
   pParse->initiateTTrans = true;
 }
#line 4144 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-3].minor.yy90 = yylhsminor.yy90;
        break;
      case 254: /* alter_add_column ::= alter_table_start ADD column_name */
#line 1773 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yylhsminor.yy90.table_name = yymsp[-2].minor.yy458;
  yylhsminor.yy90.name = yymsp[0].minor.yy0;
  pParse->initiateTTrans = true;
}
#line 4154 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[-2].minor.yy90 = yylhsminor.yy90;
        break;
      case 255: /* column_name ::= COLUMN nm */
#line 1779 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy0 = yymsp[0].minor.yy0; }
#line 4160 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 256: /* column_name ::= nm */
#line 1780 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yylhsminor.yy0 = yymsp[0].minor.yy0; }
#line 4165 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
  yymsp[0].minor.yy0 = yylhsminor.yy0;
        break;
      case 257: /* alter_column_def ::= alter_add_column typedef */
#line 1784 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_column_def_init(&pParse->create_column_def, yymsp[-1].minor.yy90.table_name, &yymsp[-1].minor.yy90.name, &yymsp[0].minor.yy320);
  create_ck_constraint_parse_def_init(&pParse->create_ck_constraint_parse_def);
  create_fk_constraint_parse_def_init(&pParse->create_fk_constraint_parse_def);
  sql_create_column_start(pParse);
}
#line 4176 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 258: /* cmd ::= alter_add_constraint FOREIGN KEY LP eidlist RP REFERENCES nm eidlist_opt matcharg refargs defer_subclause_opt */
#line 1792 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_fk_def_init(&pParse->create_fk_def, yymsp[-11].minor.yy90.table_name, &yymsp[-11].minor.yy90.name, yymsp[-7].minor.yy542, &yymsp[-4].minor.yy0, yymsp[-3].minor.yy542,
                     yymsp[-2].minor.yy42, yymsp[-1].minor.yy42, yymsp[0].minor.yy42);
  sql_create_foreign_key(pParse);
}
#line 4185 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 259: /* cmd ::= alter_add_constraint CHECK LP expr RP */
#line 1798 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
    create_ck_def_init(&pParse->create_ck_def, yymsp[-4].minor.yy90.table_name, &yymsp[-4].minor.yy90.name, &yymsp[-1].minor.yy192);
    sql_create_check_contraint(pParse);
}
#line 4193 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 260: /* cmd ::= alter_add_constraint unique_spec LP sortlist RP */
#line 1803 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  create_index_def_init(&pParse->create_index_def, yymsp[-4].minor.yy90.table_name, &yymsp[-4].minor.yy90.name, yymsp[-1].minor.yy542, yymsp[-3].minor.yy42,
                        SORT_ORDER_ASC, false);
  sql_create_index(pParse);
}
#line 4202 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 261: /* unique_spec ::= UNIQUE */
#line 1810 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy42 = SQL_INDEX_TYPE_CONSTRAINT_UNIQUE; }
#line 4207 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 262: /* unique_spec ::= PRIMARY KEY */
#line 1811 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy42 = SQL_INDEX_TYPE_CONSTRAINT_PK; }
#line 4212 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 263: /* cmd ::= alter_table_start RENAME TO nm */
#line 1813 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
    rename_entity_def_init(&pParse->rename_entity_def, yymsp[-3].minor.yy458, &yymsp[0].minor.yy0);
    pParse->initiateTTrans = true;
    sql_alter_table_rename(pParse);
}
#line 4221 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 264: /* cmd ::= ALTER TABLE fullname DROP CONSTRAINT nm */
#line 1819 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  drop_constraint_def_init(&pParse->drop_constraint_def, yymsp[-3].minor.yy197, &yymsp[0].minor.yy0, false);
  pParse->initiateTTrans = true;
  sql_drop_constraint(pParse);
}
#line 4230 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 265: /* cmd ::= alter_table_start enable CHECK CONSTRAINT nm */
#line 1825 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
    enable_entity_def_init(&pParse->enable_entity_def, ENTITY_TYPE_CK, yymsp[-4].minor.yy458,
                           &yymsp[0].minor.yy0, yymsp[-3].minor.yy537);
    sql_alter_ck_constraint_enable(pParse);
}
#line 4239 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 266: /* with ::= */
#line 1837 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{yymsp[1].minor.yy81 = 0;}
#line 4244 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 267: /* with ::= WITH wqlist */
#line 1838 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-1].minor.yy81 = yymsp[0].minor.yy81; }
#line 4249 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 268: /* with ::= WITH RECURSIVE wqlist */
#line 1839 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[-2].minor.yy81 = yymsp[0].minor.yy81; }
#line 4254 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 269: /* wqlist ::= nm eidlist_opt AS LP select RP */
#line 1841 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-5].minor.yy81 = sqlWithAdd(pParse, 0, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy542, yymsp[-1].minor.yy509); /*A-overwrites-X*/
}
#line 4261 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 270: /* wqlist ::= wqlist COMMA nm eidlist_opt AS LP select RP */
#line 1844 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-7].minor.yy81 = sqlWithAdd(pParse, yymsp[-7].minor.yy81, &yymsp[-5].minor.yy0, yymsp[-4].minor.yy542, yymsp[-1].minor.yy509);
}
#line 4268 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 271: /* typedef ::= TEXT */
      case 272: /* typedef ::= STRING_KW */ yytestcase(yyruleno==272);
#line 1850 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_STRING; }
#line 4274 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 273: /* typedef ::= SCALAR */
#line 1852 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_SCALAR; }
#line 4279 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 274: /* typedef ::= BOOL */
      case 275: /* typedef ::= BOOLEAN */ yytestcase(yyruleno==275);
#line 1854 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_BOOLEAN; }
#line 4285 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 276: /* typedef ::= VARBINARY */
#line 1856 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_VARBINARY; }
#line 4290 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 277: /* typedef ::= UUID */
#line 1857 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_UUID; }
#line 4295 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 278: /* typedef ::= ANY */
#line 1858 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_ANY; }
#line 4300 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 279: /* typedef ::= ARRAY */
#line 1859 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_ARRAY; }
#line 4305 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 280: /* typedef ::= MAP */
#line 1860 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_MAP; }
#line 4310 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 281: /* char_len ::= LP INTEGER RP */
#line 1872 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  (void) yymsp[-2].minor.yy42;
  (void) yymsp[-1].minor.yy0;
}
#line 4318 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 282: /* typedef ::= VARCHAR char_len */
#line 1878 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{
  yymsp[-1].minor.yy320.type = FIELD_TYPE_STRING;
  (void) yymsp[0].minor.yy42;
}
#line 4326 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 283: /* number_typedef ::= NUMBER */
#line 1885 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_NUMBER; }
#line 4331 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 284: /* number_typedef ::= DOUBLE */
#line 1886 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_DOUBLE; }
#line 4336 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 285: /* number_typedef ::= INT|INTEGER_KW */
#line 1887 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_INTEGER; }
#line 4341 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 286: /* number_typedef ::= UNSIGNED */
#line 1888 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_UNSIGNED; }
#line 4346 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      case 287: /* number_typedef ::= DECIMAL */
#line 1889 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"
{ yymsp[0].minor.yy320.type = FIELD_TYPE_DECIMAL; }
#line 4351 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
        break;
      default:
      /* (288) input ::= ecmd */ yytestcase(yyruleno==288);
      /* (289) explain ::= */ yytestcase(yyruleno==289);
      /* (290) cmdx ::= cmd (OPTIMIZED OUT) */ assert(yyruleno!=290);
      /* (291) savepoint_opt ::= SAVEPOINT */ yytestcase(yyruleno==291);
      /* (292) savepoint_opt ::= */ yytestcase(yyruleno==292);
      /* (293) cmd ::= create_table create_table_args with_opts create_table_end */ yytestcase(yyruleno==293);
      /* (294) create_table_args ::= LP columnlist RP */ yytestcase(yyruleno==294);
      /* (295) with_opts ::= WITH engine_opts */ yytestcase(yyruleno==295);
      /* (296) with_opts ::= */ yytestcase(yyruleno==296);
      /* (297) columnlist ::= columnlist COMMA tcons */ yytestcase(yyruleno==297);
      /* (298) columnlist ::= columnlist COMMA column_def create_column_end */ yytestcase(yyruleno==298);
      /* (299) columnlist ::= column_def create_column_end */ yytestcase(yyruleno==299);
      /* (300) column_def ::= column_name_and_type carglist */ yytestcase(yyruleno==300);
      /* (301) columnlist ::= tcons (OPTIMIZED OUT) */ assert(yyruleno!=301);
      /* (302) carglist ::= carglist ccons */ yytestcase(yyruleno==302);
      /* (303) carglist ::= */ yytestcase(yyruleno==303);
      /* (304) ccons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=304);
      /* (305) tcons ::= check_constraint_def (OPTIMIZED OUT) */ assert(yyruleno!=305);
      /* (306) defer_subclause_opt ::= defer_subclause (OPTIMIZED OUT) */ assert(yyruleno!=306);
      /* (307) resolvetype ::= raisetype (OPTIMIZED OUT) */ assert(yyruleno!=307);
      /* (308) selectnowith ::= oneselect (OPTIMIZED OUT) */ assert(yyruleno!=308);
      /* (309) oneselect ::= values */ yytestcase(yyruleno==309);
      /* (310) sclp ::= selcollist COMMA */ yytestcase(yyruleno==310);
      /* (311) as ::= ID|STRING */ yytestcase(yyruleno==311);
      /* (312) join_nm ::= ID|INDEXED */ yytestcase(yyruleno==312);
      /* (313) join_nm ::= JOIN_KW */ yytestcase(yyruleno==313);
      /* (314) expr ::= term (OPTIMIZED OUT) */ assert(yyruleno!=314);
      /* (315) type_func ::= CHAR */ yytestcase(yyruleno==315);
      /* (316) exprlist ::= nexprlist */ yytestcase(yyruleno==316);
      /* (317) foreach_clause ::= FOR EACH ROW */ yytestcase(yyruleno==317);
      /* (318) trnm ::= nm */ yytestcase(yyruleno==318);
      /* (319) tridxby ::= */ yytestcase(yyruleno==319);
      /* (320) cmd ::= alter_column_def carglist create_column_end */ yytestcase(yyruleno==320);
      /* (321) typedef ::= number_typedef (OPTIMIZED OUT) */ assert(yyruleno!=321);
        break;
/********** End reduce actions ************************************************/
  };
  assert( yyruleno<sizeof(yyRuleInfo)/sizeof(yyRuleInfo[0]) );
  yygoto = yyRuleInfo[yyruleno].lhs;
  yysize = yyRuleInfo[yyruleno].nrhs;
  yyact = yy_find_reduce_action(yymsp[-yysize].stateno,(YYCODETYPE)yygoto);
  if( yyact <= YY_MAX_SHIFTREDUCE ){
    if( yyact>YY_MAX_SHIFT ){
      yyact += YY_MIN_REDUCE - YY_MIN_SHIFTREDUCE;
    }
    yymsp -= yysize-1;
    yypParser->yytos = yymsp;
    yymsp->stateno = (YYACTIONTYPE)yyact;
    yymsp->major = (YYCODETYPE)yygoto;
    yyTraceShift(yypParser, yyact);
  }else{
    assert( yyact == YY_ACCEPT_ACTION );
    yypParser->yytos -= yysize;
    yy_accept(yypParser);
  }
}

/*
** The following code executes when the parse fails
*/
#ifndef YYNOERRORRECOVERY
static void yy_parse_failed(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sFail!\n",yyTracePrompt);
  }
#endif
  while( yypParser->yytos>yypParser->yystack ) yy_pop_parser_stack(yypParser);
  /* Here code is inserted which will be executed whenever the
  ** parser fails */
/************ Begin %parse_failure code ***************************************/
/************ End %parse_failure code *****************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}
#endif /* YYNOERRORRECOVERY */

/*
** The following code executes when a syntax error first occurs.
*/
static void yy_syntax_error(
  yyParser *yypParser,           /* The parser */
  int yymajor,                   /* The major type of the error token */
  sqlParserTOKENTYPE yyminor         /* The minor type of the error token */
){
  sqlParserARG_FETCH;
#define TOKEN yyminor
/************ Begin %syntax_error code ****************************************/
#line 32 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.y"

  UNUSED_PARAMETER(yymajor);  /* Silence some compiler warnings */
  assert( TOKEN.z[0] );  /* The tokenizer always gives us a token */
  if (yypParser->is_fallback_failed && TOKEN.isReserved) {
    diag_set(ClientError, ER_SQL_KEYWORD_IS_RESERVED, pParse->line_count,
             pParse->line_pos, TOKEN.n, TOKEN.z, TOKEN.n, TOKEN.z);
  } else {
    diag_set(ClientError, ER_SQL_SYNTAX_NEAR_TOKEN, pParse->line_count, TOKEN.n,
             TOKEN.z);
  }
  pParse->is_aborted = true;
#line 4456 "/build/usr/src/debug/tarantool-2.10.0~beta2/src/box/sql/parse.c"
/************ End %syntax_error code ******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/*
** The following is executed when the parser accepts
*/
static void yy_accept(
  yyParser *yypParser           /* The parser */
){
  sqlParserARG_FETCH;
#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sAccept!\n",yyTracePrompt);
  }
#endif
#ifndef YYNOERRORRECOVERY
  yypParser->yyerrcnt = -1;
#endif
  assert( yypParser->yytos==yypParser->yystack );
  /* Here code is inserted which will be executed whenever the
  ** parser accepts */
/*********** Begin %parse_accept code *****************************************/
/*********** End %parse_accept code *******************************************/
  sqlParserARG_STORE; /* Suppress warning about unused %extra_argument variable */
}

/* The main parser program.
** The first argument is a pointer to a structure obtained from
** "sqlParserAlloc" which describes the current state of the parser.
** The second argument is the major token number.  The third is
** the minor token.  The fourth optional argument is whatever the
** user wants (and specified in the grammar) and is available for
** use by the action routines.
**
** Inputs:
** <ul>
** <li> A pointer to the parser (an opaque structure.)
** <li> The major token number.
** <li> The minor token number.
** <li> An option argument of a grammar-specified type.
** </ul>
**
** Outputs:
** None.
*/
void sqlParser(
  void *yyp,                   /* The parser */
  int yymajor,                 /* The major token code number */
  sqlParserTOKENTYPE yyminor       /* The value for the token */
  sqlParserARG_PDECL               /* Optional %extra_argument parameter */
){
  YYMINORTYPE yyminorunion;
  unsigned int yyact;   /* The parser action. */
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  int yyendofinput;     /* True if we are at the end of input */
#endif
#ifdef YYERRORSYMBOL
  int yyerrorhit = 0;   /* True if yymajor has invoked an error */
#endif
  yyParser *yypParser;  /* The parser */

  yypParser = (yyParser*)yyp;
  assert( yypParser->yytos!=0 );
#if !defined(YYERRORSYMBOL) && !defined(YYNOERRORRECOVERY)
  yyendofinput = (yymajor==0);
#endif
  sqlParserARG_STORE;

#ifndef NDEBUG
  if( yyTraceFILE ){
    fprintf(yyTraceFILE,"%sInput '%s'\n",yyTracePrompt,yyTokenName[yymajor]);
  }
#endif

  do{
    yyact = yy_find_shift_action(yypParser,(YYCODETYPE)yymajor);
    if( yyact <= YY_MAX_SHIFTREDUCE ){
      yy_shift(yypParser,yyact,yymajor,yyminor);
#ifndef YYNOERRORRECOVERY
      yypParser->yyerrcnt--;
#endif
      yymajor = YYNOCODE;
    }else if( yyact <= YY_MAX_REDUCE ){
      yy_reduce(yypParser,yyact-YY_MIN_REDUCE);
    }else{
      assert( yyact == YY_ERROR_ACTION );
      yyminorunion.yy0 = yyminor;
#ifdef YYERRORSYMBOL
      int yymx;
#endif
#ifndef NDEBUG
      if( yyTraceFILE ){
        fprintf(yyTraceFILE,"%sSyntax Error!\n",yyTracePrompt);
      }
#endif
#ifdef YYERRORSYMBOL
      /* A syntax error has occurred.
      ** The response to an error depends upon whether or not the
      ** grammar defines an error token "ERROR".  
      **
      ** This is what we do if the grammar does define ERROR:
      **
      **  * Call the %syntax_error function.
      **
      **  * Begin popping the stack until we enter a state where
      **    it is legal to shift the error symbol, then shift
      **    the error symbol.
      **
      **  * Set the error count to three.
      **
      **  * Begin accepting and shifting new tokens.  No new error
      **    processing will occur until three tokens have been
      **    shifted successfully.
      **
      */
      if( yypParser->yyerrcnt<0 ){
        yy_syntax_error(yypParser,yymajor,yyminor);
      }
      yymx = yypParser->yytos->major;
      if( yymx==YYERRORSYMBOL || yyerrorhit ){
#ifndef NDEBUG
        if( yyTraceFILE ){
          fprintf(yyTraceFILE,"%sDiscard input token %s\n",
             yyTracePrompt,yyTokenName[yymajor]);
        }
#endif
        yy_destructor(yypParser, (YYCODETYPE)yymajor, &yyminorunion);
        yymajor = YYNOCODE;
      }else{
        while( yypParser->yytos >= yypParser->yystack
            && yymx != YYERRORSYMBOL
            && (yyact = yy_find_reduce_action(
                        yypParser->yytos->stateno,
                        YYERRORSYMBOL)) >= YY_MIN_REDUCE
        ){
          yy_pop_parser_stack(yypParser);
        }
        if( yypParser->yytos < yypParser->yystack || yymajor==0 ){
          yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
          yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
          yypParser->yyerrcnt = -1;
#endif
          yymajor = YYNOCODE;
        }else if( yymx!=YYERRORSYMBOL ){
          yy_shift(yypParser,yyact,YYERRORSYMBOL,yyminor);
        }
      }
      yypParser->yyerrcnt = 3;
      yyerrorhit = 1;
#elif defined(YYNOERRORRECOVERY)
      /* If the YYNOERRORRECOVERY macro is defined, then do not attempt to
      ** do any kind of error recovery.  Instead, simply invoke the syntax
      ** error routine and continue going as if nothing had happened.
      **
      ** Applications can set this macro (for example inside %include) if
      ** they intend to abandon the parse upon the first syntax error seen.
      */
      yy_syntax_error(yypParser,yymajor, yyminor);
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      yymajor = YYNOCODE;
      
#else  /* YYERRORSYMBOL is not defined */
      /* This is what we do if the grammar does not define ERROR:
      **
      **  * Report an error message, and throw away the input token.
      **
      **  * If the input token is $, then fail the parse.
      **
      ** As before, subsequent error messages are suppressed until
      ** three input tokens have been successfully shifted.
      */
      if( yypParser->yyerrcnt<=0 ){
        yy_syntax_error(yypParser,yymajor, yyminor);
      }
      yypParser->yyerrcnt = 3;
      yy_destructor(yypParser,(YYCODETYPE)yymajor,&yyminorunion);
      if( yyendofinput ){
        yy_parse_failed(yypParser);
#ifndef YYNOERRORRECOVERY
        yypParser->yyerrcnt = -1;
#endif
      }
      yymajor = YYNOCODE;
#endif
    }
  }while( yymajor!=YYNOCODE && yypParser->yytos>yypParser->yystack
         PARSER_ERROR_CHECK);
#ifndef NDEBUG
  if( yyTraceFILE ){
    yyStackEntry *i;
    char cDiv = '[';
    fprintf(yyTraceFILE,"%sReturn. Stack=",yyTracePrompt);
    for(i=&yypParser->yystack[1]; i<=yypParser->yytos; i++){
      fprintf(yyTraceFILE,"%c%s", cDiv, yyTokenName[i->major]);
      cDiv = ' ';
    }
    fprintf(yyTraceFILE,"]\n");
  }
#endif
  return;
}
